@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Kalender",
-    "To-dos" : "Opgaver",
+    "Tasks" : "Opgaver",
     "Personal" : "Personligt",
     "{actor} created calendar {calendar}" : "{actor} oprettede kalenderen {calendar}",
     "You created calendar {calendar}" : "Du oprettede kalenderen {calendar}",
@@ -143,22 +143,37 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Konfigurerer en CalDAV-konto",
     "Configures a CardDAV account" : "Konfigurerer en CardDAV-konto",
     "Events" : "Begivenheder",
-    "Tasks" : "Opgaver",
     "Untitled task" : "Unavngivet opgave",
     "Completed on %s" : "Fuldført den %s",
     "Due on %s by %s" : "Forfalder på %s til %s",
     "Due on %s" : "Forfalder på %s",
+    "DAV system address book" : "DAV system adressebog",
+    "No outstanding DAV system address book sync." : "Ingen udestående synkronisering af DAV-systemets adressebog.",
+    "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "DAV-systemets adressebogssynkronisering er ikke kørt endnu, da din instans har mere end 1000 brugere, eller fordi der opstod en fejl. Kør det manuelt ved at kalde \"occ dav:sync-system-addressbook\".",
+    "WebDAV endpoint" : "WebDAV endpoint",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Kunne ikke kontrollere, at din webserver er korrekt konfigureret til at tillade filsynkronisering over WebDAV. Tjek venligst manuelt.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Din webserver er endnu ikke sat korrekt op til at tillade filsynkronisering, fordi WebDAV-grænsefladen ser ud til at være i stykker.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Din webserver er korrekt konfigureret til at tillade filsynkronisering over WebDAV.",
     "Migrated calendar (%1$s)" : "Migreret kalender (%1$s)",
     "Calendars including events, details and attendees" : "Kalendere indeholdende begivenheder, detaljer og deltagere",
     "Contacts and groups" : "Kontakter og grupper",
     "WebDAV" : "WebDAV",
-    "WebDAV endpoint" : "WebDAV endpoint",
+    "First day" : "Første dag",
+    "Last day (inclusive)" : "Sidste dag (indklusiv)",
+    "Short absence status" : "Kort fraværsstatus",
+    "Long absence Message" : "Langt fravær besked",
     "Save" : "Gem",
+    "Disable absence" : "Deaktiver fravær",
+    "Absence saved" : "Fraværet er gemt",
+    "Failed to save your absence settings" : "Kunne ikke gemme dine fraværsindstillinger",
+    "Absence cleared" : "Fravær fjernet",
+    "Failed to clear your absence settings" : "Kunne ikke rydde dine fraværsindstillinger",
     "Time zone:" : "Tidszone:",
     "to" : "til",
     "Delete slot" : "Slet slot",
     "No working hours set" : "Arbejdstider er ikke sat",
     "Add slot" : "Tilføj slot",
+    "Weekdays" : "Hverdage",
     "Monday" : "Mandag",
     "Tuesday" : "Tirsdag",
     "Wednesday" : "Onsdag",
@@ -166,12 +181,16 @@ OC.L10N.register(
     "Friday" : "Fredag",
     "Saturday" : "Lørdag",
     "Sunday" : "Søndag",
+    "Pick a start time for {dayName}" : "Vælg et starttidspunkt for {dayName}",
+    "Pick a end time for {dayName}" : "Vælg et sluttidspunkt for {dayName}",
     "Automatically set user status to \"Do not disturb\" outside of availability to mute all notifications." : "Indstil automatisk brugerstatus til \"Forstyr ikke\" uden for tilgængelighed for at slå alle notifikationer fra.",
     "Failed to load availability" : "Kunne ikke indlæse tilgængelighed",
     "Saved availability" : "Gemt tilgængelighed",
     "Failed to save availability" : "Kunne ikke gemme tilgængelighed",
     "Availability" : "tilgængelighed",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Hvis du konfigurerer din arbejdstid, vil andre brugere se, når du er fraværende, når de booker et møde.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Hvis du konfigurerer dine arbejdstider, vil andre se, når du er fraværende, når de booker et møde.",
+    "Absence" : "Fravær",
+    "Configure your next absence period." : "Konfigurer din næste fraværsperiode.",
     "Calendar server" : "Kalenderserver",
     "Send invitations to attendees" : "Send invitation til deltagere",
     "Automatically generate a birthday calendar" : "Generer en fødselsdagskalender automatisk",
@@ -188,6 +207,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Kontakt venligst arrangøren direkte.",
     "Are you accepting the invitation?" : "Accepter du invitationen?",
     "Tentative" : "Foreløbig",
-    "Your attendance was updated successfully." : "Dit tilstedeværelse blev opdateret."
+    "Your attendance was updated successfully." : "Dit tilstedeværelse blev opdateret.",
+    "To-dos" : "Opgaver",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Hvis du konfigurerer din arbejdstid, vil andre brugere se, når du er fraværende, når de booker et møde."
 },
 "nplurals=2; plural=(n != 1);");
