@@ -2,7 +2,7 @@ OC.L10N.register(
     "dav",
     {
     "Calendar" : "Kalender",
-    "To-dos" : "Aufgaben",
+    "Tasks" : "Aufgaben",
     "Personal" : "Persönlich",
     "{actor} created calendar {calendar}" : "{actor} hat den Kalender {calendar} erstellt",
     "You created calendar {calendar}" : "Du hast den Kalender {calendar} erstellt",
@@ -143,7 +143,6 @@ OC.L10N.register(
     "Configures a CalDAV account" : "Ein CalDAV-Konto einrichten",
     "Configures a CardDAV account" : "Ein CardDAV-Konto einrichten",
     "Events" : "Ereignisse",
-    "Tasks" : "Aufgaben",
     "Untitled task" : "Unbenannte Aufgabe",
     "Completed on %s" : "Erledigt am %s",
     "Due on %s by %s" : "Fällig am %s von %s",
@@ -151,11 +150,14 @@ OC.L10N.register(
     "DAV system address book" : "DAV-Systemadressbuch",
     "No outstanding DAV system address book sync." : "Keine ausstehende Synchronisierung des DAV-Systemadressbuchs",
     "The DAV system address book sync has not run yet as your instance has more than 1000 users or because an error occurred. Please run it manually by calling \"occ dav:sync-system-addressbook\"." : "Die Synchronisierung des DAV-Systemadressbuchs wurde noch nicht ausgeführt, da deine Instanz mehr als 1000 Benutzer hat oder weil ein Fehler aufgetreten ist. Bitte führe sie manuell aus, indem du \"occ dav:sync-system-addressbook\" ausführst.",
+    "WebDAV endpoint" : "WebDAV-Endpunkt",
+    "Could not check that your web server is properly set up to allow file synchronization over WebDAV. Please check manually." : "Es konnte nicht überprüft werden, ob dein Webserver ordnungsgemäß eingerichtet ist, um Dateisynchronisation über WebDAV zu ermöglichen. Bitte überprüfe dies manuell.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Dein Webserver ist noch nicht hinreichend für Datei-Synchronisierung konfiguriert, da die WebDAV-Schnittstelle vermutlich nicht funktioniert.",
+    "Your web server is properly set up to allow file synchronization over WebDAV." : "Dein Webserver ist ordnungsgemäß eingerichtet um Dateisynchronisation über WebDAV zu ermöglichen.",
     "Migrated calendar (%1$s)" : "Migrierter Kalender (%1$s)",
     "Calendars including events, details and attendees" : "Kalender mit Terminen, Details und Teilnehmern",
     "Contacts and groups" : "Kontakte und Gruppen",
     "WebDAV" : "WebDAV",
-    "WebDAV endpoint" : "WebDAV-Endpunkt",
     "First day" : "Erster Tag",
     "Last day (inclusive)" : "Letzter Tag (Inklusive)",
     "Short absence status" : "Kurze Abwesenheits Meldung",
@@ -171,6 +173,7 @@ OC.L10N.register(
     "Delete slot" : "Slot löschen",
     "No working hours set" : "Keine Arbeitszeiten konfiguriert",
     "Add slot" : "Slot hinzufügen",
+    "Weekdays" : "Wochentage",
     "Monday" : "Montag",
     "Tuesday" : "Dienstag",
     "Wednesday" : "Mittwoch",
@@ -185,7 +188,7 @@ OC.L10N.register(
     "Saved availability" : "Verfügbarkeit gespeichert",
     "Failed to save availability" : "Fehler beim Speichern der Verfügbarkeit",
     "Availability" : "Verfügbarkeit",
-    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten konfigurierst, können andere Benutzer sehen, wann du nicht im Büro bist, wenn sie eine Besprechung buchen.",
+    "If you configure your working hours, other people will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten konfigurierst, können andere Benutzer sehen, wann du nicht im Büro bist, wenn sie eine Besprechung buchen.",
     "Absence" : "Abwesenheit",
     "Configure your next absence period." : "Richte deinen nächsten Abwesenheitszeitraum ein.",
     "Calendar server" : "Kalender-Server",
@@ -204,6 +207,8 @@ OC.L10N.register(
     "Please contact the organizer directly." : "Bitte den Organisator direkt kontaktieren.",
     "Are you accepting the invitation?" : "Die Einladung annehmen?",
     "Tentative" : "Vorläufig",
-    "Your attendance was updated successfully." : "Dein Teilnehmerstatus wurde aktualisiert."
+    "Your attendance was updated successfully." : "Dein Teilnehmerstatus wurde aktualisiert.",
+    "To-dos" : "Aufgaben",
+    "If you configure your working hours, other users will see when you are out of office when they book a meeting." : "Wenn du deine Arbeitszeiten konfigurierst, können andere Benutzer sehen, wann du nicht im Büro bist, wenn sie eine Besprechung buchen."
 },
 "nplurals=2; plural=(n != 1);");
