@@ -38,9 +38,9 @@ OC.L10N.register(
     "Edit locally" : "Редактировать локально",
     "Open" : "Открыть",
     "Delete file" : "Удалить файл",
-    "Delete folder" : "Удалить каталог",
+    "Delete folder" : "Удалить папку",
     "Disconnect storage" : "Отсоединить хранилище",
-    "Leave this share" : "Отказаться от совместного доступа к этому ресурсу",
+    "Leave this share" : "Перестать использовать общий ресурс",
     "Could not load info for file \"{file}\"" : "Не удаётся загрузить информацию для файла \"{file}\"",
     "Files" : "Файлы",
     "Details" : "Подробно",
@@ -101,13 +101,13 @@ OC.L10N.register(
     "Your storage is almost full ({usedSpacePercent}%)." : "Ваше хранилище почти заполнено (использовано {usedSpacePercent} %).",
     "_matches \"{filter}\"_::_match \"{filter}\"_" : ["соответствуют «{filter}»","соответствуют «{filter}»","соответствуют «{filter}»","соответствует «{filter}»"],
     "View in folder" : "Посмотреть в каталоге",
-    "Direct link was copied (only works for users who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых есть доступ к этому файлу или папке. ",
+    "Direct link was copied (only works for people who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых уже есть доступ к этому файлу или папке. ",
     "Path" : "Путь",
     "_%n byte_::_%n bytes_" : ["%n байт","%n байта","%n байт","%n байт"],
     "Favorited" : "Избранное",
     "Favorite" : "Добавить в избранное",
-    "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
-    "New folder" : "Новый каталог",
+    "Copy direct link (only works for people who have access to this file/folder)" : "Копировать прямую ссылку (она сработает только для пользователей, у которых уже есть доступ к этому файлу или каталогу)",
+    "New folder" : "Новая папка",
     "Create new folder" : "Создать папку",
     "Upload file" : "Загрузить файл",
     "Recent" : "Недавно изменённые",
@@ -121,13 +121,13 @@ OC.L10N.register(
     "You removed {file} from your favorites" : "Вы удалили «{file}» из избранного",
     "Favorites" : "Избранные",
     "File changes" : "Изменения файлов",
-    "Created by {user}" : "Создано {user}",
-    "Changed by {user}" : "Изменено {user}",
-    "Deleted by {user}" : "Удалено {user}",
-    "Restored by {user}" : "Восстановлено {user}",
-    "Renamed by {user}" : "Переименовано {user}",
-    "Moved by {user}" : "Перемещено {user}",
-    "\"remote user\"" : "«пользователь с другого сервера»",
+    "Created by {user}" : "Создано пользователем {user}",
+    "Changed by {user}" : "Изменено пользователем {user}",
+    "Deleted by {user}" : "Удалено пользователем {user}",
+    "Restored by {user}" : "Восстановлено пользователем {user}",
+    "Renamed by {user}" : "Переименовано пользователем {user}",
+    "Moved by {user}" : "Перемещено пользователем {user}",
+    "\"remote account\"" : "«пользователь другого сервера»",
     "You created {file}" : "Вы создали «{file}»",
     "You created an encrypted file in {file}" : "Вы создали зашифрованный файл в «{file}»",
     "{user} created {file}" : "{user} создал(а) «{file}»",
@@ -175,9 +175,10 @@ OC.L10N.register(
     "Drag and drop files here to upload" : "Перетаскивайте файлы сюда для загрузки",
     "Your have used your space quota and cannot upload files anymore" : "Вы использовали всё доступное вам место и не можете больше загружать файлы",
     "You don’t have permission to upload or create files here" : "У вас нет прав на создание или загрузку файлов в эту папку.",
-    "Upload successful" : "Загружено успешно",
     "\"{displayName}\" action executed successfully" : "Действие «{displayName}» выполнено успешно",
     "\"{displayName}\" action failed" : "Действие «{displayName}» завершилось неудачно",
+    "Toggle selection for file \"{displayName}\"" : "Установить или снять выделение файла «{displayName}»",
+    "Toggle selection for folder \"{displayName}\"" : "Установить или снять выделение папки «{displayName}»",
     "Rename file" : "Переименовать файл",
     "File name" : "Имя файла",
     "Folder name" : "Имя папки",
@@ -185,16 +186,15 @@ OC.L10N.register(
     "Download file {name}" : "Скачать файл {name}",
     "\"{name}\" is not an allowed filetype." : "«{name}» не является допустимым типом файла.",
     "{newName} already exists." : "«{newName}» уже существует.",
-    "\"{char}\" is not allowed inside a file name." : "\"{char}\" не допускается внутри имени файла.",
+    "\"{char}\" is not allowed inside a file name." : "Символ «{char}» не допускается внутри имени файла.",
     "Name cannot be empty" : "Имя не может быть пустым",
     "Another entry with the same name already exists" : "Другая запись с таким названием уже существует",
     "Renamed \"{oldName}\" to \"{newName}\"" : "Переименовано «{oldName}» в \"{newName}\"",
     "Could not rename \"{oldName}\", it does not exist any more" : "Не удалось переименовать \"{oldName}\", его больше не существует",
     "The name \"{newName}\" is already used in the folder \"{dir}\". Please choose a different name." : "Имя \"{newName}\" уже используется в каталоге \"{dir}\". Выберите другое имя.",
     "Could not rename \"{oldName}\"" : "Не удалось переименовать «{oldName}»",
-    "Could not copy {file}. {message}" : "Ошибка копирования «{file}». {message}",
-    "Could not move {file}. {message}" : "Ошибка перемещения «{file}». {message}",
     "Total rows summary" : "Количество строк в общем",
+    "Toggle selection for all files and folders" : "Установить или снять выделение всех файлов и папок",
     "\"{displayName}\" failed on some elements " : "«{displayName}» неудачно для некоторых элементов",
     "\"{displayName}\" batch action executed successfully" : "Пакетное действие \"{displayName}\" выполнено успешно",
     "List of files and folders." : "Список файлов и каталогов.",
@@ -206,6 +206,8 @@ OC.L10N.register(
     "{relative}% used" : "Использовано {relative}%",
     "Could not refresh storage stats" : "Не удалось обновить данные об использовании хранилища",
     "Your storage is full, files can not be updated or synced anymore!" : "Ваше хранилище переполнено, файлы больше не могут быть обновлены или синхронизированы.",
+    "Create" : "Создать",
+    "A file or folder with that name already exists." : "Файл или папка с этим именем уже существуют.",
     "Transfer ownership of a file or folder" : "Изменение владельца файла или папки",
     "Choose file or folder to transfer" : "Выберите файл или папку для передачи владения",
     "Change" : "Изменить",
@@ -220,7 +222,6 @@ OC.L10N.register(
     "Select file or folder to link to" : "Выберите файл или папку для создания ссылки",
     "Choose file" : "Выберите файл",
     "Choose {file}" : "Выберан {file}",
-    "Add" : "Добавить",
     "Loading current folder" : "Загрузка текущей папки",
     "No files in here" : "Здесь нет файлов",
     "Upload some content or sync with your devices!" : "Загрузите что-нибудь или синхронизируйте со своими устройствами!",
@@ -232,11 +233,16 @@ OC.L10N.register(
     "Switch to list view" : "Переключение в режим просмотра списка",
     "Switch to grid view" : "Переключиться на режим просмотра сеткой",
     "Error during upload: {message}" : "Ошибка при загрузке: {message}",
+    "Error during upload, status code {status}" : "Ошибка при передаче на сервер. Сообщение об ошибке: {status}",
     "Unknown error during upload" : "Неизвестная ошибка при загрузке",
     "Open the files app settings" : "Открыть параметры приложения «Файлы»",
     "Files settings" : "Настройки файлов",
     "File cannot be accessed" : "Не удалось получить доступ к файлу",
+    "The file could not be found or you do not have permissions to view it. Ask the sender to share it." : "Не удалось найти файл или у вас отсутствуют права на его просмотр.  Попросите отправителя предоставить вам доступ к этому файлу.",
+    "Your files" : "Ваши файлы",
+    "Open in files" : "Открыть в приложении Файлы",
     "Sort favorites first" : "Сначала избранное",
+    "Sort folders before files" : "Начинать список с папок",
     "Show hidden files" : "Показывать скрытые файлы",
     "Crop image previews" : "Обрезать пред. просмотр",
     "Enable the grid view" : "Включить режим просмотра сеткой",
@@ -251,34 +257,61 @@ OC.L10N.register(
     "Unable to change the favourite state of the file" : "Не удалось изменить состояние «избранный» этого файла.",
     "Error while loading the file data" : "Не удалось загрузить данные файла",
     "Pick a template for {name}" : "Выбрать шаблон для {name}",
-    "Create" : "Создать",
     "Create a new file with the selected template" : "Создать файл на основе шаблона",
     "Creating file" : "Создание файла",
     "Blank" : "Пустой",
     "Unable to create new file from template" : "Не удалось создать файл на основе шаблона",
     "Delete permanently" : "Удалить навсегда",
+    "Delete and unshare" : "Удалить и закрыть общий доступ",
+    "Leave these shares" : "Отказаться от доступа к общим ресурсам",
+    "Disconnect storages" : "Отключить хранилища",
+    "Delete files" : "Удалить файлы",
+    "Delete folders" : "Удалить папки",
+    "You are about to delete {count} items." : "Подтвердите удаление {count} объекта (-ов).",
+    "Confirm deletion" : "Подтвердить удаление",
+    "Cancel" : "Отменить",
+    "Deletion cancelled" : "Удаление отменено",
     "Destination is not a folder" : "Указанное назначение не является папкой",
     "This file/folder is already in that directory" : "Файл или папка уже расположены в этой папке",
     "You cannot move a file/folder onto itself or into a subfolder of itself" : "Папка или файл не могут быть перемещены во вложенную папку или в себя",
+    "(copy)" : "(копия)",
+    "(copy %n)" : "(копия %n)",
+    "Move cancelled" : "Перемещение отменено",
     "A file or folder with that name already exists in this folder" : "В этой папке уже есть файл или папка с этим именем",
-    "The files is locked" : "Файлы заблокированы",
+    "The files are locked" : "Файлы заблокированы",
     "The file does not exist anymore" : "Файл больше не существует",
     "Choose destination" : "Выберите место назначения",
     "Copy to {target}" : "Скопировать в «{target}»",
     "Move to {target}" : "Переместить в «{target}»",
     "Cancelled move or copy operation" : "Копирование или перемещение отменено",
-    "Open folder {displayName}" : "Открыть каталог {displayName}",
-    "Open in Files" : "Открыть в Файлах",
+    "Move or copy operation failed" : "Ошибка перемещение или копирования",
+    "Open folder {displayName}" : "Открыть папку «{displayName}»",
+    "Open in Files" : "Открыть в приложении «Файлы»",
     "Open details" : "Открыть подробности",
+    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
+    "Filename" : "Имя файла",
+    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
     "Create new templates folder" : "Создать новую папку шаблонов",
     "Templates" : "Шаблоны",
-    "Unable to initialize the templates directory" : "Не удалось инициализировать каталог шаблонов",
-    "Created new folder \"{name}\"" : "Создана новая папка \"{name}\"",
+    "New template folder" : "Новая папка шаблонов",
+    "In folder" : "В папке",
+    "Search in folder: {folder}" : "Поиск в папке: «{folder}»",
     "One of the dropped files could not be processed" : "Один из перетащенных файлов не может быть обработан",
-    "Uploading \"{filename}\" failed" : "Загрузка \"{filename}\" не удалась",
-    "_{folderCount} folder_::_{folderCount} folders_" : ["{count} папка","{count} папки","{count} папок","{count} папки"],
-    "_{fileCount} file_::_{fileCount} files_" : ["{count} файл","{count} файла","{count} файлов","{count} файла"],
-    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {count} папка","один файл и {count} папки","один файл и {count} папок","один файл и {count} папки"],
+    "Your browser does not support the Filesystem API. Directories will not be uploaded" : "Папки не будут загружены, так как используемый браузер не поддерживает работу с файловой системой.",
+    "No files to upload" : "Не выбрано ни одного файла для передачи на сервер",
+    "Unable to create the directory {directory}" : "Не удалось создать папку «{directory}»",
+    "Some files could not be uploaded" : "Некоторые файлы не могут быть загружены",
+    "Files uploaded successfully" : "Файлы успешно обновлены",
+    "No files to process" : "Не ни одного файла для обработки",
+    "Some files could not be copied" : "Некоторые файлы не могут быть скопированы",
+    "Some files could not be moved" : "Некоторые файлы не могут быть перемещены",
+    "Files copied successfully" : "Файлы успешно скопированы",
+    "Files moved successfully" : "Файлы успешно перемещены",
+    "Conflicts resolution skipped" : "Разрешение конфликтов пропущено",
+    "Upload cancelled" : "Передача на сервер отменена",
+    "_{folderCount} folder_::_{folderCount} folders_" : ["{folderCount} папка","{folderCount} папки","{folderCount} папок","{folderCount} папки"],
+    "_{fileCount} file_::_{fileCount} files_" : ["{fileCount} файл","{fileCount} файла","{fileCount} файлов","{fileCount} файла"],
+    "_1 file and {folderCount} folder_::_1 file and {folderCount} folders_" : ["один файл и {folderCount} папка","один файл и {folderCount} папки","один файл и {folderCount} папок","один файл и {folderCount} папки"],
     "_{fileCount} file and 1 folder_::_{fileCount} files and 1 folder_" : ["{fileCount} файл и одна папка","{fileCount} файла и одна папка","{fileCount} файлов и одна папка","{fileCount} файла и одна папка"],
     "{fileCount} files and {folderCount} folders" : "файлов: {fileCount}, папок: {folderCount}",
     "List of favorites files and folders." : "Список избранных файлов и каталогов.",
@@ -286,6 +319,10 @@ OC.L10N.register(
     "Files and folders you mark as favorite will show up here" : "Здесь будут показаны файлы и каталоги, отмеченные как избранные",
     "All files" : "Все файлы",
     "List of your files and folders." : "Список ваших файлов и каталогов.",
+    "Personal Files" : "Личные Файлы",
+    "List of your files and folders that are not shared." : "Список ваших неопубликованных файлов и папок.",
+    "No personal files found" : "Личные файлы не найдены",
+    "Files that are not shared will show up here." : "Файлы, которые не опубликованы, показаны здесь.",
     "List of recently modified files and folders." : "Список недавно измененных файлов и директорий.",
     "No recently modified files" : "Нет недавно измененных файлов",
     "Files and folders you recently modified will show up here." : "Здесь будут показаны недавно изменённые файлы и папки",
@@ -295,21 +332,12 @@ OC.L10N.register(
     "The files you are trying to upload exceed the maximum size for file uploads on this server." : "Файлы, которые вы пытаетесь передать, превышают лимит максимального размера на этом сервере.",
     "Text file" : "Текстовый файл",
     "New text file.txt" : "Новый текстовый файл.txt",
+    "Direct link was copied (only works for users who have access to this file/folder)" : "Внутренняя ссылка скопирована. Она может быть использована только пользователями, у которых есть доступ к этому файлу или папке. ",
+    "Copy direct link (only works for users who have access to this file/folder)" : "Копировать прямую ссылку (работает только для пользователей с правами доступа к этому файлу или каталогу)",
     "You can only favorite a single file or folder at a time" : "Одновременно можно выбрать только один файл или папку",
-    "Search users" : "Поиск пользователей",
-    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
-    "Cancel" : "Отменить",
-    "Set up templates folder" : "Указать папку шаблонов",
-    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
-    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
-    "Deleted files" : "Корзина",
-    "Shares" : "Общие ресурсы",
-    "Shared with others" : "Доступные для других",
-    "Shared with you" : "Доступные для вас",
-    "Deleted shares" : "Удалённые общие ресурсы",
-    "Pending shares" : "Ожидающие общие ресурсы",
     "This file has the tag {tag}" : "Файлу назначана метка «{tag}»",
     "This file has the tags {firstTags} and {lastTag}" : "Файлу назначены метки «{firstTags}» и «{lastTag}»",
+    "\"remote user\"" : "«пользователь с другого сервера»",
     "Select the row for {displayName}" : "Выбрать строку для {displayName}",
     "Open folder {name}" : "Открыть папку {name}",
     "Unselect all" : "Отменить выделение для всех",
@@ -319,6 +347,16 @@ OC.L10N.register(
     "This list is not fully rendered for performances reasons. The files will be rendered as you navigate through the list." : "Этот список отображается не полностью из соображений производительности. Файлы будут отображаться по мере перемещения по списку.",
     "Search for an account" : "Поиск по учетной записи",
     "Choose" : "Выберите",
-    "No files or folders have been deleted yet" : "Файлы или папки еще не удалены"
+    "No files or folders have been deleted yet" : "Файлы или папки еще не удалены",
+    "You might not have have permissions to view it, ask the sender to share it" : "У вас отсутствуют права на просмотр файла, попросите предоставить их у владельца общего ресурса",
+    "Set up templates folder" : "Указать папку шаблонов",
+    "Toggle %1$s sublist" : "Переключить %1$s подсписок",
+    "Toggle grid view" : "Включить или отключить режим просмотра сеткой",
+    "Shares" : "Общие ресурсы",
+    "Shared with others" : "Доступные для других",
+    "Shared with you" : "Доступные для вас",
+    "Deleted shares" : "Удалённые общие ресурсы",
+    "Pending shares" : "Ожидающие общие ресурсы",
+    "The files is locked" : "Файлы заблокированы"
 },
 "nplurals=4; plural=(n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<12 || n%100>14) ? 1 : n%10==0 || (n%10>=5 && n%10<=9) || (n%100>=11 && n%100<=14)? 2 : 3);");
