@@ -79,7 +79,7 @@ OC.L10N.register(
     "Wrong path, file/folder does not exist" : "Väärä polku, tiedostoa/kansiota ei ole olemassa",
     "Could not create share" : "Jaon luominen epäonnistui",
     "Invalid permissions" : "Virheelliset käyttöoikeudet",
-    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
+    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
     "Group sharing is disabled by the administrator" : "Ylläpitäjä on estänyt ryhmäjakamisen",
     "Please specify a valid group" : "Määritä kelvollinen ryhmä",
     "Public link sharing is disabled by the administrator" : "Ylläpitäjä on estänyt julkisen linkin jakamisen",
@@ -87,7 +87,6 @@ OC.L10N.register(
     "Public upload is only possible for publicly shared folders" : "Julkinen lähettäminen on mahdollista vain julkisesti jaetuille kansioille",
     "Sharing %s sending the password by Nextcloud Talk failed because Nextcloud Talk is not enabled" : "Kohteen %s jakaminen lähettämällä salasana Nextcloud Talkin kautta epäonnistui, koska Nextcloud Talk ei ole käytössä",
     "Sharing %1$s failed because the back end does not allow shares from type %2$s" : "Kohteen %1$s jakaminen epäonnistui, koska tietovarasto ei salli %2$s tyyppisiä jakoja",
-    "Invalid date, date format must be YYYY-MM-DD" : "Virheellinen päiväys, päivämäärän muodon tulee olla VVVV-KK-PP",
     "You cannot share to a Circle if the app is not enabled" : "Et voi jakaa piiriin, jos sovellusta ei ole aktivoitu",
     "Please specify a valid circle" : "Määritä kelvollinen piiri",
     "Sharing %s failed because the back end does not support room shares" : "Kohteen %s jakaminen epäonnistui, koska taustaosa ei tue huonejakoja",
@@ -108,23 +107,16 @@ OC.L10N.register(
     "You received {share} as a share by {user}" : "Vastaanotit jaon {share} käyttäjältä {user}",
     "You received {share} to group {group} as a share by {user}" : "Vastaanotit jaon {share} ryhmään {group} käyttäjältä {user}",
     "Accept" : "Hyväksy",
-    "Reject" : "Hylkää",
+    "Decline" : "Kieltäydy",
     "Sharing" : "Jakaminen",
-    "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
+    "Accept shares from other accounts and groups by default" : "Hyväksy jaot muilta tileiltä ja ryhmiltä oletusarvoisesti",
     "Set default folder for accepted shares" : "Aseta oletuskansio hyväksytyille jaoille",
     "Reset" : "Palauta",
     "Reset folder to system default" : "Palauta kansio järjestelmän oletukseksi",
     "Choose a default folder for accepted shares" : "Valitse oletuskansio hyväksytyille jaoille",
     "Invalid path selected" : "Virheellinen polku valittu",
     "Unknown error" : "Tuntematon virhe",
-    "Allow editing" : "Salli muokkaus",
-    "Read only" : "Vain luku",
-    "Allow upload and editing" : "Salli lähetys ja muokkaus",
-    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
-    "Custom permissions" : "Mukautetut oikeudet",
-    "Read" : "Lue",
-    "Upload" : "Lähetä",
-    "Edit" : "Muokkaa",
+    "Open Sharing Details" : "Avaa jakamisen yksityiskohdat",
     "group" : "ryhmä",
     "conversation" : "keskustelu",
     "remote" : "etä",
@@ -139,8 +131,6 @@ OC.L10N.register(
     "Internal link" : "Sisäinen linkki",
     "Cannot copy, please copy the link manually" : "Kopioiminen ei onnistu. Kopioi linkki manuaalisesti",
     "Copy internal link to clipboard" : "Kopioi sisäinen linkki leikepöydälle",
-    "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
-    "Only works for users with access to this file" : "Toimii vain käyttäjille, joilla on käyttöoikeus tähän tiedostoon",
     "Link copied" : "Linkki kopioitu",
     "Please enter the following required information before creating the share" : "Anna seuraavat vaaditut tiedot, ennen kuin luot jaon",
     "Password protection (enforced)" : "Salasanasuojaus (pakotettu)",
@@ -151,6 +141,7 @@ OC.L10N.register(
     "Create share" : "Luo jako",
     "Cancel" : "Peruuta",
     "Customize link" : "Mukauta linkkiä",
+    "Generate QR code" : "Luo QR-koodi",
     "Add another link" : "Lisää toinen linkki",
     "Create a new share link" : "Luo uusi jakolinkki",
     "Shared via link by {initiator}" : "Jaettu linkin kautta käyttäjältä {initiator}",
@@ -166,6 +157,7 @@ OC.L10N.register(
     "View only" : "Vain katselu",
     "Can edit" : "Voi muokata",
     "File drop" : "Tiedoston pudotus",
+    "Custom permissions" : "Mukautetut oikeudet",
     "Search for share recipients" : "Etsi jaon vastaanottajia",
     "No recommendations. Start typing." : "Ei suosituksia. Aloita kirjoittaminen.",
     "Resharing is not allowed" : "Uudelleenjako ei ole sallittu",
@@ -177,31 +169,38 @@ OC.L10N.register(
     "Guest" : "Vieras",
     "Group" : "Ryhmä",
     "Email" : "Sähköposti",
-    "Circle" : "Piiri",
+    "Team" : "Tiimi",
     "Talk conversation" : "Talk-keskustelu",
     "Deck board" : "Deck-taulu",
     "on {server}" : "palvelimella {server}",
+    "Allow upload and editing" : "Salli lähetys ja muokkaus",
+    "Allow editing" : "Salli muokkaus",
     "Advanced settings" : "Lisäasetukset",
     "Share label" : "Jaon nimi",
     "Set password" : "Aseta salasana",
     "Password" : "Salasana",
     "Password expires {passwordExpirationTime}" : "Salasana vanhenee {passwordExpirationTime}",
     "Password expired" : "Salasana vanheni",
+    "Video verification" : "Videovarmistus",
     "Set expiration date" : "Aseta vanhenemispäivä",
     "Expiration date" : "Vanhenemispäivä",
     "Hide download" : "Piilota lataus",
-    "Video verification" : "Videovarmistus",
     "Allow download" : "Salli lataus",
     "Note to recipient" : "Huomio vastaanottajalle",
     "Enter a note for the share recipient" : "Lisää muistiinpano jaon vastaanottajalle",
+    "Read" : "Lue",
     "Create" : "Luo",
+    "Edit" : "Muokkaa",
     "Share" : "Jaa",
     "Delete share" : "Poista jako",
-    "Share with" : "Jaa",
-    "Save share" : "Tallenna jako",
+    "Share with {userName}" : "Jaa käyttäjän {userName} kanssa",
+    "Share with group" : "Jaa ryhmän kanssa",
+    "Share in conversation" : "Jaa keskustelussa",
+    "Share with remote group" : "Jaa etäryhmän kanssa",
+    "Share with guest" : "Jaa vieraan kanssa",
     "Update share" : "Päivitä jako",
+    "Save share" : "Tallenna jako",
     "Others with access" : "Muut, joilla on käyttöoikeus",
-    "No other users with access found" : "Ei löytynyt muita käyttäjiä, joilla olisi käyttöoikeus",
     "Toggle list of others with access to this directory" : "Vaihda näkymää kansioon käyttöoikeuden omaavista käyttäjistä",
     "Toggle list of others with access to this file" : "Vaihda näkymää tiedostoon käyttöoikeuden omaavista käyttäjistä",
     "Unable to load the shares list" : "Jakolistan haku epäonnistui",
@@ -213,6 +212,9 @@ OC.L10N.register(
     "_Reject share_::_Reject shares_" : ["Hylkää jako","Hylkää jaot"],
     "_Restore share_::_Restore shares_" : ["Palauta jako","Palauta jaot"],
     "Shared" : "Jaettu",
+    "Shared multiple times with different people" : "Jaettu useita kertoja eri ihmisten kanssa",
+    "Shared by {ownerDisplayName}" : "Jakanut {ownerDisplayName}",
+    "Show sharing options" : "Näytä jakamisen valinnat",
     "Link to a file" : "Linkki tiedostoon",
     "Error creating the share: {errorMessage}" : "Virhe luotaessa jakoa: {errorMessage}",
     "Error creating the share" : "Virhe jakoa luotaessa",
@@ -269,11 +271,16 @@ OC.L10N.register(
     "Something happened. Unable to accept the share." : "Jotain tapahtui. Jakoa ei voitu hyväksyä.",
     "Something happened. Unable to reject the share." : "Tapahtui virhe. Ei voida hylätä jakoa.",
     "No expiration date set" : "Ei vanhenemispäivää asetettu",
-    "Allow creating" : "Salli luominen",
-    "Allow deleting" : "Salli poistaminen",
-    "Allow resharing" : "Salli uudelleenjakaminen",
-    "Expiration date enforced" : "Vanhenemispäivä pakotettu",
-    "Password protect" : "Suojaa salasanalla",
+    "Please specify a valid user" : "Määritä kelvollinen käyttäjä",
+    "Accept user and group shares by default" : "Hyväksy käyttäjä- ja ryhmäjaot oletuksena",
+    "Read only" : "Vain luku",
+    "File drop (upload only)" : "Tiedostojen pudotus (vain lähetys)",
+    "Upload" : "Lähetä",
+    "Only works for users with access to this folder" : "Toimii vain käyttäjille, joilla on oikeus tähän kansioon",
+    "Only works for users with access to this file" : "Toimii vain käyttäjille, joilla on käyttöoikeus tähän tiedostoon",
+    "Circle" : "Piiri",
+    "Update" : "Päivitä",
+    "No other users with access found" : "Ei löytynyt muita käyttäjiä, joilla olisi käyttöoikeus",
     "No entries found in this folder" : "Ei kohteita tässä kansiossa",
     "Name" : "Nimi",
     "Share time" : "Jakamisen ajankohta",
@@ -282,7 +289,6 @@ OC.L10N.register(
     "the item was removed" : "kohde poistettiin",
     "the link expired" : "linkki vanheni",
     "sharing is disabled" : "jakaminen on poistettu käytöstä",
-    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin.",
-    "Update" : "Päivitä"
+    "For more info, please ask the person who sent this link." : "Kysy lisätietoja henkilöltä, jolta sait linkin."
 },
 "nplurals=2; plural=(n != 1);");
