@@ -10,6 +10,8 @@ OC.L10N.register(
     "Time" : "Hora",
     "Line {line}" : "Línea {line}",
     "Download logs" : "Descargar bitácoras",
+    "Ctrl" : "Ctrl",
+    "Relative" : "Relativo",
     "Application" : "Aplicación",
     "Message" : "Mensaje",
     "Show details" : "Mostrar detalles",
