@@ -2,7 +2,7 @@ OC.L10N.register(
     "photos",
     {
     "Public link" : "Publiskā saite",
-    "Photos" : "Bildes",
+    "Photos" : "Fotoattēli",
     "Videos" : "Video",
     "Albums" : "Albumi",
     "Folders" : "Mapes",
@@ -22,10 +22,13 @@ OC.L10N.register(
     "An error occurred" : "Gadījās kļūda",
     "Favorite" : "Favorīts",
     "Go back" : "Atpakaļ",
-    "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta ",
+    "Dates" : "Datumi",
+    "Add folder" : "Pievienot mapi",
+    "Home" : "Sākums",
     "View" : "Skats",
     "Remove from favorites" : "Noņemt no izlases",
     "Add" : "Pievienot",
-    "Details" : "Detaļas"
+    "Details" : "Detaļas",
+    "Invalid location selected" : "Ir izvēlēta nederīga atrašanās vieta "
 },
 "nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
