@@ -40,31 +40,28 @@ OC.L10N.register(
     "You deleted app password \"{token}\"" : "คุณลบรหัสผ่านแอป \"{token}\" แล้ว",
     "Security" : "ความปลอดภัย",
     "Your <strong>password</strong> or <strong>email</strong> was modified" : "มีการเปลี่ยนแปลง<strong>รหัสผ่าน</strong>หรือ<strong>อีเมล</strong>ของคุณ",
-    "Apps" : "แอป",
+    "Settings" : "การตั้งค่า",
     "Wrong password" : "รหัสผ่านไม่ถูกต้อง",
     "Saved" : "บันทึกแล้ว",
-    "No user supplied" : "ไม่ได้ระบุผู้ใช้",
     "Authentication error" : "เกิดข้อผิดพลาดในการตรวจสอบสิทธิ์",
-    "Please provide an admin recovery password; otherwise, all user data will be lost." : "โปรดใส่รหัสผ่านกู้คืนของผู้ดูแลระบบ มิฉะนั้น ข้อมูลของผู้ใช้ทั้งหมดจะหายไป",
     "Wrong admin recovery password. Please check the password and try again." : "รหัสผ่านกู้คืนของผู้ดูแลระบบไม่ถูกต้อง กรุณาตรวจสอบรหัสผ่านและลองอีกครั้ง",
     "Administrator documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
     "User documentation" : "เอกสารประกอบสำหรับผู้ใช้",
     "Email setting test" : "ทดสอบการตั้งค่าอีเมล",
     "Well done, %s!" : "เยี่ยมยอด คุณ %s!",
     "A problem occurred while sending the email. Please revise your settings. (Error: %s)" : "เกิดปัญหาขณะส่งอีเมล กรุณาแก้ไขการตั้งค่าของคุณ (ข้อผิดพลาด: %s)",
-    "Users" : "ผู้ใช้",
-    "Invalid user" : "ผู้ใช้ไม่ถูกต้อง",
+    "Invalid account" : "บัญชีไม่ถูกต้อง",
     "Invalid mail address" : "ที่อยู่อีเมลไม่ถูกต้อง",
     "Settings saved" : "บันทึกการตั้งค่าแล้ว",
     "Unable to change full name" : "ไม่สามารถเปลี่ยนชื่อเต็ม",
     "Your %s account was created" : "สร้างบัญชี %s ของคุณแล้ว",
     "Welcome to your %s account, you can add, protect, and share your data." : "ยินดีต้อนรับสู่บัญชี %s ของคุณ คุณสามารถเพิ่ม ป้องกัน และแชร์ข้อมูลของคุณ",
-    "Your username is: %s" : "ชื่อผู้ใช้ของคุณคือ: %s",
     "Set your password" : "ตั้งรหัสผ่านของคุณ",
     "Go to %s" : "ไปที่ %s",
     "Install Client" : "ติดตั้งไคลเอ็นต์",
-    "Settings" : "การตั้งค่า",
+    "Apps" : "แอป",
     "Personal" : "ส่วนตัว",
+    "Users" : "ผู้ใช้",
     "Additional settings" : "การตั้งค่าเพิ่มเติม",
     "Sharing" : "การแชร์",
     "Calendar" : "ปฏิทิน",
@@ -85,30 +82,16 @@ OC.L10N.register(
     "Allow public uploads" : "อนุญาตให้อัปโหลดสาธารณะ",
     "Always ask for a password" : "ถามรหัสผ่านเสมอ",
     "Enforce password protection" : "บังคับใช้การป้องกันรหัสผ่าน",
-    "Exclude groups from sharing" : "ยกเว้นกลุ่มจากการแชร์",
-    "These groups will still be able to receive shares, but not to initiate them." : "กลุ่มนี้จะยังคงสามารถรับการแชร์ แต่ไม่สามารถสร้างแชร์ใหม่",
     "Set default expiration date for shares" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์",
     "Enforce expiration date" : "บังคับให้มีวันหมดอายุ",
     "Set default expiration date for shares to other servers" : "ตั้งวันหมดอายุค่าเริ่มต้นสำหรับการแชร์ไปยังเซิร์ฟเวอร์อื่น",
     "Two-Factor Authentication" : "การยืนยันสองปัจจัย",
     "Save changes" : "บันทึกการเปลี่ยนแปลง",
-    "All" : "ทั้งหมด",
-    "Limit app usage to groups" : "จำกัดการใช้แอปสำหรับกลุ่ม",
-    "No results" : "ไม่มีผลลัพธ์",
-    "Update to {version}" : "อัปเดตเป็น {version}",
+    "Update to {update}" : "อัปเดตเป็น {update}",
     "Remove" : "ลบออก",
     "Disable" : "ปิดใช้งาน",
-    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นขั้นต่ำของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
-    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นสูงสุดของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
-    "This app cannot be installed because the following dependencies are not fulfilled:" : "ไม่สามารถติดตั้งแอปนี้ เนื่องจากสิ่งที่พึ่งพาต่อไปนี้ยังไม่ครบ:",
-    "View in store" : "ดูในร้านค้า",
-    "Visit website" : "เข้าสู่เว็บไซต์",
-    "Report a bug" : "รายงานข้อผิดพลาด",
-    "Admin documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
-    "Developer documentation" : "เอกสารประกอบสำหรับนักพัฒนา",
-    "This app is supported via your current Nextcloud subscription." : "แอปนี้รองรับผ่านการเป็นสมาชิก Nextcloud ปัจจุบันของคุณ",
     "Featured" : "แนะนำ",
-    "Update to {update}" : "อัปเดตเป็น {update}",
+    "This app is supported via your current Nextcloud subscription." : "แอปนี้รองรับผ่านการเป็นสมาชิก Nextcloud ปัจจุบันของคุณ",
     "Icon" : "ไอคอน",
     "Name" : "ชื่อ",
     "Version" : "รุ่น",
@@ -117,6 +100,25 @@ OC.L10N.register(
     "No apps found for your version" : "ไม่พบแอปสำหรับรุ่นของคุณ",
     "Disable all" : "ปิดใช้งานทั้งหมด",
     "_%n app has an update available_::_%n apps have an update available_" : ["%n แอปมีอัปเดตใหม่"],
+    "Loading" : "กำลังโหลด",
+    "Description" : "คำอธิบาย",
+    "Details" : "รายละเอียด",
+    "All" : "ทั้งหมด",
+    "Limit app usage to groups" : "จำกัดการใช้แอปสำหรับกลุ่ม",
+    "No results" : "ไม่มีผลลัพธ์",
+    "Update to {version}" : "อัปเดตเป็น {version}",
+    "This app has no minimum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นขั้นต่ำของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
+    "This app has no maximum Nextcloud version assigned. This will be an error in the future." : "แอปนี้ไม่ได้ระบุรุ่นสูงสุดของ Nextcloud ซึ่งอาจเป็นปัญหาในอนาคตได้",
+    "This app cannot be installed because the following dependencies are not fulfilled:" : "ไม่สามารถติดตั้งแอปนี้ เนื่องจากสิ่งที่พึ่งพาต่อไปนี้ยังไม่ครบ:",
+    "Categories" : "หมวดหมู่",
+    "Resources" : "ทรัพยากร",
+    "Documentation" : "เอกสารประกอบ",
+    "Report a bug" : "รายงานข้อผิดพลาด",
+    "View in store" : "ดูในร้านค้า",
+    "Visit website" : "เข้าสู่เว็บไซต์",
+    "Admin documentation" : "เอกสารประกอบสำหรับผู้ดูแลระบบ",
+    "Developer documentation" : "เอกสารประกอบสำหรับนักพัฒนา",
+    "Changelog" : "บันทึกการเปลี่ยนแปลง",
     "Marked for remote wipe" : "ระบุสำหรับการล้างระยะไกลแล้ว",
     "Device settings" : "การตั้งค่าอุปกรณ์",
     "Allow filesystem access" : "อนุญาตให้เข้าถึงระบบไฟล์",
@@ -128,6 +130,7 @@ OC.L10N.register(
     "{productName} Android app" : "แอป {productName} สำหรับ Android",
     "{productName} Talk for iOS" : "{productName} Talk สำหรับ iOS",
     "{productName} Talk for Android" : "{productName} Talk สำหรับ Android",
+    "Sync client" : "ไคลเอ็นต์ซิงค์",
     "This session" : "เซสชันนี้",
     "Device" : "อุปกรณ์",
     "Last activity" : "กิจกรรมล่าสุด",
@@ -136,7 +139,7 @@ OC.L10N.register(
     "App name" : "ชื่อแอป",
     "Create new app password" : "สร้างรหัสผ่านแอปใหม่",
     "Error while creating device token" : "ข้อผิดพลาดขณะสร้างโทเค็นอุปกรณ์",
-    "Username" : "ชื่อผู้ใช้",
+    "Login" : "เข้าสู่ระบบ",
     "Password" : "รหัสผ่าน",
     "Show QR code for mobile apps" : "แสดงคิวอาร์โค้ดสำหรับแอปมือถือ",
     "Could not copy app password. Please copy it manually." : "ไม่สามารถคัดลอกรหัสผ่านแอป โปรดคัดลอกด้วยตนเอง",
@@ -158,9 +161,8 @@ OC.L10N.register(
     "New password" : "รหัสผ่านใหม่",
     "Change password" : "เปลี่ยนรหัสผ่าน",
     "Picture provided by original account" : "ใช้รูปภาพจากบัญชีเดิม",
-    "Details" : "รายละเอียด",
-    "Email options" : "ตัวเลือกอีเมล",
     "Primary email for password reset and notifications" : "อีเมลหลักสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน",
+    "Email options" : "ตัวเลือกอีเมล",
     "Remove primary email" : "ลบอีเมลหลักออก",
     "Delete email" : "ลบอีเมล",
     "Additional email address {index}" : "ที่อยู่อีเมลเพิ่มเติม {index}",
@@ -180,19 +182,14 @@ OC.L10N.register(
     "Quota" : "โควต้า",
     "Language" : "ภาษา",
     "Avatar" : "ภาพแทนตัว",
+    "Username" : "ชื่อผู้ใช้",
     "Group admin for" : "ผู้ดูแลกลุ่มสำหรับ",
     "User backend" : "แบ็กเอนด์ของผู้ใช้",
     "Storage location" : "สถานที่จัดเก็บข้อมูล",
     "Last login" : "เข้าสู่ระบบล่าสุด",
-    "You do not have permissions to see the details of this user" : "คุณไม่มีสิทธิ์ที่จะดูรายละเอียดของผู้ใช้นี้",
     "Add user to group" : "เพิ่มผู้ใช้เข้ากลุ่ม",
-    "Set user as admin for" : "ตั้งผู้ใช้เป็นผู้ดูแลระบบสำหรับ",
-    "Select user quota" : "เลือกโควต้าผู้ใช้",
     "{size} used" : "ใช้ไป {size}",
-    "Delete user" : "ลบผู้ใช้",
-    "Wipe all devices" : "ล้างอุปกรณ์ทั้งหมด",
-    "Disable user" : "ปิดใช้งานผู้ใช้",
-    "Enable user" : "เปิดใช้งานผู้ใช้",
+    "Delete account" : "ลบบัญชี",
     "Resend welcome email" : "ส่งอีเมลยินดีต้อนรับซ้ำ",
     "In case of lost device or exiting the organization, this can remotely wipe the Nextcloud data from all devices associated with {userid}. Only works if the devices are connected to the internet." : "ในกรณีที่อุปกรณ์สูญหายหรือออกจากองค์กร ตัวเลือกนี้สามารถล้างข้อมูล Nextcloud จากทุกอุปกรณ์ที่เชื่อมโยงกับ {userid} จากระยะไกล การล้างข้อมูลจะทำงานเฉพาะเมื่ออุปกรณ์เชื่อมต่อกับอินเทอร์เน็ตเท่านั้น",
     "Remote wipe of devices" : "ล้างอุปกรณ์จากระยะไกล",
@@ -201,10 +198,8 @@ OC.L10N.register(
     "Account deletion" : "การลบบัญชี",
     "Delete {userid}'s account" : "ลบบัญชีของ {userid}",
     "Welcome mail sent!" : "ส่งอีเมลยินดีต้อนรับแล้ว!",
-    "Toggle user actions menu" : "เปิด-ปิด เมนูการกระทำผู้ใช้",
     "Done" : "เสร็จสิ้น",
     "Edit" : "แก้ไข",
-    "Show user backend" : "แสดงแบ็กเอนด์ของผู้ใช้",
     "Show storage path" : "แสดงเส้นทางจัดเก็บข้อมูล",
     "Show last login" : "แสดงการเข้าสู่ระบบล่าสุด",
     "Send email" : "ส่งอีเมล",
@@ -213,9 +208,7 @@ OC.L10N.register(
     "Passwordless authentication requires a secure connection." : "การรับรองความถูกต้องแบบไร้รหัสผ่านต้องใช้การเชื่อมต่อที่ปลอดภัย",
     "Add WebAuthn device" : "เพิ่มอุปกรณ์ WebAuthn",
     "Please authorize your WebAuthn device." : "โปรดอนุมัติอุปกรณ์ WebAuthn ของคุณ",
-    "Name your device" : "ตั้งชื่ออุปกรณ์ของคุณ",
     "Adding your device …" : "กำลังเพิ่มอุปกรณ์ …",
-    "Server error while trying to add WebAuthn device" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามเพิ่มอุปกรณ์ WebAuthn",
     "Server error while trying to complete WebAuthn device registration" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามลงทะเบียนอุปกรณ์ WebAuthn ให้เสร็จสิ้น",
     "Unnamed device" : "อุปกรณ์ไม่มีชื่อ",
     "Passwordless Authentication" : "การรับรองความถูกต้องแบบไร้รหัสผ่าน",
@@ -223,12 +216,7 @@ OC.L10N.register(
     "No devices configured." : "ไม่มีอุปกรณ์ที่กำหนดค่า",
     "The following devices are configured for your account:" : "อุปกรณ์เหล่านี้มีการกำหนดค่าสำหรับบัญชีของคุณแล้ว:",
     "Your browser does not support WebAuthn." : "เบราว์เซอร์ของคุณไม่รองรับ WebAuthn",
-    "{license}-licensed" : "สัญญาอนุญาต {license}",
-    "Changelog" : "บันทึกการเปลี่ยนแปลง",
-    "by {author}\n{license}" : "โดย {author}\n{license}",
-    "Active users" : "ผู้ใช้ที่ใช้งานอยู่",
     "Admins" : "ผู้ดูแลระบบ",
-    "Disabled users" : "ผู้ใช้ที่ปิดใช้งาน",
     "Group name" : "ชื่อกลุ่ม",
     "Sending…" : "กำลังส่ง....",
     "Email sent" : "ส่งอีเมลแล้ว",
@@ -258,9 +246,7 @@ OC.L10N.register(
     "Error while updating device token name" : "ข้อผิดพลาดขณะอัปเดตชื่อโทเค็นอุปกรณ์",
     "Error while updating device token scope" : "ข้อผิดพลาดขณะอัปเดตขอบเขตโทเค็นอุปกรณ์",
     "There were too many requests from your network. Retry later or contact your administrator if this is an error." : "มีการส่งคำขอจากเครือข่ายของคุณมากเกินไป กรุณาลองอีกครั้งในภายหลัง หรือติดต่อผู้ดูแลระบบหากเป็นข้อผิดพลาด",
-    "Documentation" : "เอกสารประกอบ",
     "Forum" : "ฟอรัม",
-    "Login" : "เข้าสู่ระบบ",
     "SSL" : "SSL",
     "Open documentation" : "เปิดเอกสารประกอบ",
     "It is important to set up this server to be able to send emails, like for password reset and notifications." : "การตั้งค่าให้เซิร์ฟเวอร์นี้ส่งอีเมลได้ เช่น อีเมลสำหรับการตั้งรหัสผ่านใหม่และการแจ้งเตือน เป็นสิ่งสำคัญ",
@@ -273,7 +259,6 @@ OC.L10N.register(
     "Authentication" : "การตรวจสอบสิทธิ์",
     "Authentication required" : "จำเป็นต้องตรวจสอบความถูกต้อง",
     "Credentials" : "ข้อมูลส่วนตัวสำหรับเข้าระบบ",
-    "SMTP Username" : "ชื่อผู้ใช้ SMTP",
     "SMTP Password" : "รหัสผ่าน SMTP",
     "Save" : "บันทึก",
     "It's important for the security and performance of your instance that everything is configured correctly. To help you with that we are doing some automatic checks. Please see the linked documentation for more information." : "การกำหนดค่าทุกอย่างให้ถูกต้องเป็นสิ่งสำคัญสำหรับความปลอดภัยและประสิทธิภาพของเซิร์ฟเวอร์ของคุณ เพื่อช่วยคุณในเรื่องนี้ เรากำลังทำการตรวจสอบอัตโนมัติ โปรดดูเอกสารประกอบที่ลิงก์มาสำหรับข้อมูลเพิ่มเติม",
@@ -285,8 +270,12 @@ OC.L10N.register(
     "Check the security of your Nextcloud over <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">our security scan ↗</a>." : "ตรวจสอบความปลอดภัยของ Nextcloud ของคุณผ่าน<a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">การสแกนความปลอดภัยของเรา ↗</a>",
     "Reasons to use Nextcloud in your organization" : "เหตุผลที่ควรใช้ Nextcloud ในองค์กรของคุณ",
     "This community release of Nextcloud is unsupported and instant notifications are unavailable." : "รุ่นที่ออกโดยชุมชนของ Nextcloud นี้ไม่ได้รับการสนับสนุน และไม่สามารถใช้งานการแจ้งเตือนทันทีได้",
+    "No user supplied" : "ไม่ได้ระบุผู้ใช้",
+    "Please provide an admin recovery password; otherwise, all user data will be lost." : "โปรดใส่รหัสผ่านกู้คืนของผู้ดูแลระบบ มิฉะนั้น ข้อมูลของผู้ใช้ทั้งหมดจะหายไป",
     "Federated Cloud Sharing" : "คลาวด์แชร์กับสหพันธ์",
     "cURL is using an outdated %1$s version (%2$s). Please update your operating system or features such as %3$s will not work reliably." : "cURL กำลังใช้ %1$s รุ่นเก่า (%2$s) โปรดอัปเดตระบบปฏิบัติการ ไม่เช่นนั้นคุณสมบัติเช่น %3$s จะไม่สามารถทำงานอย่างมีประสิทธิภาพ",
+    "Invalid user" : "ผู้ใช้ไม่ถูกต้อง",
+    "Your username is: %s" : "ชื่อผู้ใช้ของคุณคือ: %s",
     "Enable all" : "เปิดใช้งานทั้งหมด",
     "Internet Explorer" : "Internet Explorer",
     "Edge" : "Edge",
@@ -303,25 +292,42 @@ OC.L10N.register(
     "Copy" : "คัดลอก",
     "You are about to remove the group {group}. The users will NOT be deleted." : "คุณกำลังจะลบกลุ่ม {group} ผู้ใช้ที่อยู่ในกลุ่มจะไม่ถูกลบไปด้วย",
     "Please confirm the group removal " : "กรุณายืนยันการลบกลุ่ม",
-    "png or jpg, max. 20 MB" : "png หรือ jpg สูงสุดไม่เกิน 20 MB",
     "Your email address" : "ที่อยู่อีเมลของคุณ",
+    "You do not have permissions to see the details of this user" : "คุณไม่มีสิทธิ์ที่จะดูรายละเอียดของผู้ใช้นี้",
     "Add new password" : "เพิ่มรหัสผ่านใหม่",
     "Add new email address" : "เพิ่มที่อยู่อีเมลใหม่",
+    "Set user as admin for" : "ตั้งผู้ใช้เป็นผู้ดูแลระบบสำหรับ",
+    "Select user quota" : "เลือกโควต้าผู้ใช้",
+    "Toggle user actions menu" : "เปิด-ปิด เมนูการกระทำผู้ใช้",
+    "Delete user" : "ลบผู้ใช้",
+    "Wipe all devices" : "ล้างอุปกรณ์ทั้งหมด",
+    "Disable user" : "ปิดใช้งานผู้ใช้",
+    "Enable user" : "เปิดใช้งานผู้ใช้",
     "Edit User" : "แก้ไขผู้ใช้",
     "Will be autogenerated" : "จะถูกสร้างขึ้นโดยอัตโนมัติ",
     "Add a new user" : "เพิ่มผู้ใช้ใหม่",
     "No users in here" : "ไม่มีผู้ใช้ที่นี่",
+    "Name your device" : "ตั้งชื่ออุปกรณ์ของคุณ",
+    "Server error while trying to add WebAuthn device" : "เกิดข้อผิดพลาดเซิร์ฟเวอร์ขณะกำลังพยายามเพิ่มอุปกรณ์ WebAuthn",
+    "{license}-licensed" : "สัญญาอนุญาต {license}",
+    "by {author}\n{license}" : "โดย {author}\n{license}",
     "Enter group name" : "ใส่ชื่อกลุ่ม",
     "Add group" : "เพิ่มกลุ่ม",
+    "Active users" : "ผู้ใช้ที่ใช้งานอยู่",
+    "Disabled users" : "ผู้ใช้ที่ปิดใช้งาน",
     "Default quota:" : "ค่าโควต้าเริ่มต้น:",
     "Show Languages" : "แสดงภาษา",
+    "Show user backend" : "แสดงแบ็กเอนด์ของผู้ใช้",
     "Send email to new user" : "ส่งอีเมลไปยังผู้ใช้ใหม่",
     "Not saved" : "ไม่ได้บันทึก",
     "Twitter" : "ทวิตเตอร์",
     "Enable untested app" : "เปิดใช้งานแอปที่ไม่ได้ทดสอบ",
+    "SMTP Username" : "ชื่อผู้ใช้ SMTP",
     "Expire after" : "หมดอายุหลังจาก",
     "day(s)" : "วัน",
     "Set default expiration date" : "ตั้งวันหมดอายุค่าเริ่มต้น",
-    "Exclude groups from creating link shares:" : "ยกเว้นกลุ่มจากการสร้างลิงก์แชร์:"
+    "Exclude groups from creating link shares:" : "ยกเว้นกลุ่มจากการสร้างลิงก์แชร์:",
+    "Exclude groups from sharing" : "ยกเว้นกลุ่มจากการแชร์",
+    "These groups will still be able to receive shares, but not to initiate them." : "กลุ่มนี้จะยังคงสามารถรับการแชร์ แต่ไม่สามารถสร้างแชร์ใหม่"
 },
 "nplurals=1; plural=0;");
