@@ -5,6 +5,8 @@ OC.L10N.register(
     "File is too big" : "Re vras eo ar restr",
     "The selected file is not an image." : "N'eo ket ur skeudenn ar restr choazet.",
     "The selected file cannot be read." : "N'eo ket posubl lenn ar restr choazet.",
+    "The file was uploaded" : "Kaset eo bet ar restr",
+    "No file was uploaded" : "N'eus restr ebet a zo bet kaset",
     "Invalid file provided" : "Ar restr roet n'eo ket unan aotreet",
     "No image or file provided" : "Skeudenn pe restr roet ebet",
     "Unknown filetype" : "N'eo ket anavezet stumm ar restr",
@@ -48,35 +50,15 @@ OC.L10N.register(
     "%s (incompatible)" : "%s (diglot)",
     "The following apps have been disabled: %s" : "Disaotreet eo bet ar meziantoù-mañ : %s",
     "Already up to date" : "Adnevezet dija",
-    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Ho servijour web n'eo ket bet staliet c'hoazh evit aotreañ ar c'hempredañ, peogwir e seblant etrefas WabDAV bezañ torret.",
-    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne seblant ket bezañ staliet mat evit goulenn d'ar sistem argemennoù endro. An amprouenn gant getenv(\"PATH\") a ro ur respont goullo.",
-    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Aotreet a zo bet ar stumm lenn-nemetken. Ampechiñ a ra cheñch stummoù dre an etrefas-web. Ouzhpenn-se, ar restr en deus ezhomm bezañ adlakaet da  vezañ embannapl dre dorn evit pep adneveziñ.",
-    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ho roadennoù-diaz ne droont ket gant al live \"READ COMMITTED\". Kudennoù a zo posupl kaout pa vez graet meur a ober war an dro.",
-    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "N'eus ket eus ar modul PHP \"fileinfo\". Gwelloc'h eo aotreañ ar modul-mañ evit kaout an disoc'hoù gwellañ evit dizoloeiñ ar stumm MIME.",
-    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ne oa ket posupl ober al labour Cron dre CLI. Ar gudenn deknikel-mañ a zo deuet war wel :",
-    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "N'eo ket posupl implijout arc’hwel PHP \"set_time_limit\". Galout a ra ar gudenn-se herzel skriptoù e-kreiz o labour, terriñ ar staliadur. Aotreañ an arc'hwel a zo aliet-mat.",
-    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù trolinenn ha stummoù an etrefas.",
-    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Ar roll \"{indexName}\" a vank en daolenn \"{tableName}\".",
-    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankout a ra rollioù er roadenn-diaz. Abalamour e kemer amzer ouzhpennañ rollioù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-indices\" eo posupl ouzhpennañ ar rollioù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ar rollioù ouzhpennet, goulennoù savet d'an taolennoù a vo buanaet.",
-    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Ar golonenn diret \"{columnName}\" a vank en daolenn \"{tableName}\".",
-    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankout a ra kolonennoù er roadennoù-diaz dibabapl. Abalamour e kemer amzer ouzhpennañ kolonennoù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-columns\" eo posupl ouzhpennañ ar c'holonennoù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ouzhpennet ar c'holonennoù, goulennoù savet d'an taolennoù a vo buanaet.",
-    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "An etrefas a vank dezhañ moduloù PHP aliet. Evit gwellaat ar mont en dro hag ar c'heverlec’hded ez eo kinniget kenañ o staliañ.",
-    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite a vez implijet evel ur backend ar roadenoù-diaz. Evit staliadurioù brasoc'h e vez aliet cheñch d'ur backend roadennoù-diaz all.",
-    "This is particularly recommended when using the desktop client for file synchronisation." : "Kinniget kennañ pa vez implijet ar c'hliant burev evit kempredañ ar restroù.",
-    "The PHP memory limit is below the recommended value of 512MB." : "Bevenn memor PHP a zo dindan an hini kinniget eus 512MB.",
-    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Touliadoù meziant zo a zo dalc'het gant un implijour diseñvel eus ar servijour web. M'az eo bet stalied ar meziant gant an dorn eo normal. Gwiriit an aotreoù an teuliadoù meziant mañ:",
-    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "An azgoulenn a implij  un dra diazezed war S3 evel e bern pennañ. Ar restroù pellkaset a vez  bernied ebit point war ar servijour, setut perak eo kinniget kaout 50 GB plass dieub e teuliad PHP temp. Gwiriit ar gazetenn evit munudoù an hent hag ar plass dieub. Evit gwellat ar blass, cheñchit an teuliad amzeriel e-barzh php.ini pa roit muioc'h a blass en hent.",
     "Error occurred while checking server setup" : "Ur vazi a zo bet pa omp o gwiriañ staliadur ar servijour",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Penn HTTP \"{header}\" n'eo ket stumm \"{expected}\". Posuple eo bezha ur gudenn surentez pe prevezted, kinniget eo cheñch ar stumm mañ.",
-    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Penn HTTP \"{header}\" n'eo ket stumm \"{expected}\". Perzhioù zo na labouro ket mat, kinniget eo cheñch ar stumm mañ.",
     "unknown text" : "testenn dianv",
     "Hello world!" : "Demat d'ar bed !",
     "sunny" : "heoliek",
-    "Hello {name}, the weather is {weather}" : "Demat {name}, {weather} eo an amzer",
-    "Hello {name}" : "Demat {name}",
+    "Hello {name}, the weather is {weather}" : "Demat deoc'h {name}, {weather} eo an amzer",
+    "Hello {name}" : "Demat deoc'h {name}",
     "<strong>These are your search results<script>alert(1)</script></strong>" : "<strong>Setu disoc'hoù o enklask<script>alert(1)</script></strong>",
     "new" : "nevez",
-    "_download %n file_::_download %n files_" : ["O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pelgargañ %n restr"],
+    "_download %n file_::_download %n files_" : ["O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr","O pellgargañ %n restr"],
     "The update is in progress, leaving this page might interrupt the process in some environments." : "An adnevezadenn a zo o treiñ, na zilezik ket ar bajenn, m'o all e hel beza troc'het an oberenn war endroioù zo.",
     "Update to {version}" : "Oc'h adneveziñ da {version}",
     "An error occurred." : "Ur fazi a zo bet.",
@@ -84,18 +66,17 @@ OC.L10N.register(
     "The update was unsuccessful. For more information <a href=\"{url}\">check our forum post</a> covering this issue." : "Graet eo bet an adnevesadenn; Evit muioc'h a titouroù <a href=\"{url}\">sellit ouzh gemenadenoù ar forum</a> diwar benn ze.",
     "The update was unsuccessful. Please report this issue to the <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nextcloud community</a>." : "An adnevesadenn a zo bet c'hwitet. Mar-plij, kemenit <a href=\"https://github.com/nextcloud/server/issues\" target=\"_blank\">Nexcloud community</a> eus ar gudenn.",
     "More apps" : "Muioc'h a veziantoù",
+    "No" : "Nan",
+    "Yes" : "Ya",
     "Log in" : "Kennaskañ",
-    "Logging in …" : "O kennsakañ...",
+    "Logging in …" : "O kennaskañ…",
     "Server side authentication failed!" : "Dilesa kostez servijour c'hwited !",
     "Please contact your administrator." : "Mar-plij galvit o merour",
     "An internal error occurred." : "Ur fazi diabarzh a zo bet.",
     "Please try again or contact your administrator." : "Mar-plij, klaskit en dro pe galvit o merour.",
     "Password" : "Ger-tremen",
-    "Wrong username or password." : "Anv-implijader pe ger-tremen direizh",
-    "User disabled" : "Implijer disaotreet",
     "We have detected multiple invalid login attempts from your IP. Therefore your next login is throttled up to 30 seconds." : "Gwelet on eus eo bet klasket mon-tre dro dre o IP. Ne vo posuple deoc'h klask en dro a-benn 30 eilenn.",
     "Log in with a device" : "Mon-tre gan un ardivink",
-    "Username or email" : "Anv implijer pe bostel",
     "Your account is not setup for passwordless login." : "N'eo ket arventennet ho kont evit kennaskañ hep ger-tremen.",
     "Passwordless authentication is not supported in your browser." : "Ne vez ket degemeret gant ho furcher an anaouadur hep ger-tremen.",
     "Passwordless authentication is only available over a secure connection." : "Dilesa hep ger-tremen a vez kinniget fant ur c'henstagadur sur nemetken.",
@@ -116,43 +97,30 @@ OC.L10N.register(
     "Keep your colleagues and friends in one place without leaking their private info." : "Kavit o mignoned ha genseurted en ul lec'h, hep reiñ o ditouroù prevez.",
     "Simple email app nicely integrated with Files, Contacts and Calendar." : "Ur meziant email simpl enfammet gant Restroù, Darempredoù ha Deizataer.",
     "Chatting, video calls, screensharing, online meetings and web conferencing – in your browser and with mobile apps." : "Chattañ, pellgomzadennoù video, rannañ skramm, emvodoù dre linnen, ha web brezegennoù - gant o furcherha gant o meziantoù pellgomzerioù-hezoug.",
-    "Forgot password?" : "Ger-tremen ankouaet?",
-    "Back" : "Distro",
     "Reset search" : "Adkregiñ an enklask",
+    "Search contacts …" : "Klask darempred ...",
+    "Could not load your contacts" : "N'eo ket posuple kargañ an darempredoù",
+    "No contacts found" : "Darmpred ebet kavet",
+    "Install the Contacts app" : "Stalliaén ar meziant darempredoù",
+    "Loading your contacts …" : "O kargañ o darempredoù",
+    "Looking for {term} …" : "O klask {term} ...",
     "Start typing to search" : "Krogit da skrivañ evit klask",
     "Loading more results …" : "O kargañ muioc'h a zisoc'hoù ...",
     "Load more results" : "Kagañ muioc'h a disoc'hoù",
     "Search" : "Klask",
     "No results for {query}" : "Disoc'h ebet evit {query}",
     "_Please enter {minSearchLength} character or more to search_::_Please enter {minSearchLength} characters or more to search_" : ["Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait {minSearchLength} arouez pe muioc'h evit klask","Lakait  {minSearchLength} arouez pe muioc'h evit klask"],
-    "Settings menu" : "Roll-mezioù an arventennoù",
+    "Forgot password?" : "Ger-tremen ankouaet?",
+    "Back" : "Distro",
     "Search {types} …" : "Klask {types} ...",
-    "Could not load your contacts" : "N'eo ket posuple kargañ an darempredoù",
-    "Search contacts …" : "Klask darempred ...",
-    "No contacts found" : "Darmpred ebet kavet",
-    "Show all contacts …" : "Diskwel tout an darempredoù ...",
-    "Install the Contacts app" : "Stalliaén ar meziant darempredoù",
-    "Loading your contacts …" : "O kargañ o darempredoù",
-    "Looking for {term} …" : "O klask {term} ...",
-    "No" : "Nan",
-    "Yes" : "Ya",
-    "No files in here" : "Restr ebet amañ",
-    "New folder" : "Heuliad nevez",
-    "No more subfolders in here" : "N'ez eus ket isteuliadoù all amañ",
-    "Name" : "Anv",
-    "Size" : "Ment",
-    "Modified" : "Cheñchet",
-    "\"{name}\" is an invalid file name." : "N'eo ket \"{name}\" un anv restr aotreet.",
-    "File name cannot be empty." : "N'hall ket anv ur restr bezañ goullo.",
-    "\"/\" is not allowed inside a file name." : "N'eo ket aotreet \"/\" e anv ur restr.",
-    "\"{name}\" is not an allowed filetype" : "N'eo ket \"{name}\" un doare restr aotreet",
-    "{newName} already exists" : "{newName} zo anezhañ c'hoazh",
+    "Date" : "Deiz",
+    "Today" : "Hiziv",
+    "Searching …" : "O klask ...",
+    "Settings menu" : "Roll-mezioù an arventennoù",
     "Choose" : "Dibab",
     "Copy" : "Eilañ",
     "Move" : "Diplasañ",
-    "Error loading file picker template: {error}" : "Ur fazi a zo bet en ur c'hargañ ar choazer eskelet restr : {error}",
     "OK" : "OK",
-    "Error loading message template: {error}" : "Ur fazi zo bet pa voe karget stumm skouer ar gemenadenn : [error]",
     "read-only" : "lennable nemetken",
     "_{count} file conflict_::_{count} file conflicts_" : ["{count} diemglev restr","{count} diemglev restr","{count} diemglev restr","{count} diemglev restr","{count} diemglev restr"],
     "One file conflict" : "Diemglev gant ur restr",
@@ -165,15 +133,7 @@ OC.L10N.register(
     "(all selected)" : "(dibab pep tra)",
     "({count} selected)" : "({count} dibabet)",
     "Error loading file exists template" : "Ur fazi zo bet pa voe karget ar restr",
-    "Pending" : "O c'hortoz",
-    "Home" : "Degemer",
-    "Copy to {folder}" : "Eilan e {folder}",
-    "Move to {folder}" : "Diblasañ da {folder}",
     "Saving …" : "Orc'h enrolliñ",
-    "Authentication required" : "Eus un dilesa ez eus ezhomp",
-    "This action requires you to confirm your password" : "An ober-mañ a c'houlenn e kadarnfec'h ho ker-tremen",
-    "Confirm" : "Kadarnañ",
-    "Failed to authenticate, try again" : "Dilesa c'hwitet, klaskit en dro",
     "seconds ago" : "eilenn zo",
     "Connection to server lost" : "Kelet eo bet ar c'henstagañ gant ar servijour",
     "_Problem loading page, reloading in %n second_::_Problem loading page, reloading in %n seconds_" : ["Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn","Ur gudenn zo evit kargañ ar bajenn, adkargit a ben %n eilenn"],
@@ -202,7 +162,6 @@ OC.L10N.register(
     "Collaborative tags" : "Klav rannet",
     "No tags found" : "Klav ebet kavet",
     "Personal" : "Personel",
-    "Users" : "Implijer",
     "Apps" : "Meziant",
     "Admin" : "Merour",
     "Help" : "Skoazell",
@@ -228,7 +187,6 @@ OC.L10N.register(
     "Your data directory and files are probably accessible from the internet because the .htaccess file does not work." : "O teuliad ha restroù rouadennoù a zo posuple tizhout a dalek ar roaedad, peogwir ne gerzh ket ar restr .htaccess.",
     "For information how to properly configure your server, please see the <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">documentation</a>." : "Evit kaout titouroù diwar benn penaos stumman mat o servijour, sellit ouz an <a href=\"%s\" target=\"_blank\" rel=\"noreferrer noopener\">dielvadur</a> mar-plij.",
     "Create an <strong>admin account</strong>" : "Krouiñ ur <strong>c'hont merour</strong>",
-    "Username" : "anv implijer",
     "Show password" : "Diskouez ar ger-tremen",
     "Storage & database" : "Lec'h renkañ ha roadennoù-diaz",
     "Data folder" : "Teuliat roadennoù",
@@ -236,7 +194,6 @@ OC.L10N.register(
     "Only %s is available." : "%s digarg nemetken",
     "Install and activate additional PHP modules to choose other database types." : "Lakaat ha difraeañ molladoù PHP ouzhpenn evit dibab doare roadennoù-diaz all",
     "For more details check out the documentation." : "Sellit ouz an dielladur evit munudoù ouzhpenn.",
-    "Database user" : "Roadennoù-diaz an implijourien",
     "Database password" : "Roadennoù-diaz ar gerioù-trermen",
     "Database name" : "Roadennoù-diaz an anvioù",
     "Database tablespace" : "Lec'h berniañ ar roadennoù-diaz",
@@ -253,15 +210,12 @@ OC.L10N.register(
     "This application requires JavaScript for correct operation. Please {linkstart}enable JavaScript{linkend} and reload the page." : "Ezhomp en deus ar meziant eus JavaScript evit kerzhout mat. Mar-plij, {linkstart}aotreit JavaScript{linkend} hag adkargit ar bajenn.",
     "Skip to main content" : "Kit d'an dalc'h penna",
     "Skip to navigation of app" : "Mont d'ar meziant merdeerezh",
-    "Get your own free account" : "Tapit o c'hont digoust",
     "Go to %s" : "Mont da %s",
-    "Confirm your password" : "Kadarnañ ho ker-tremen",
+    "Get your own free account" : "Tapit o c'hont digoust",
     "Connect to your account" : "Kevreit gant o c'hont",
     "Please log in before granting %1$s access to your %2$s account." : "Kit-tre a raok reiñ %1$s tremen d'o c'hont %2$s.",
     "If you are not trying to set up a new device or app, someone is trying to trick you into granting them access to your data. In this case do not proceed and instead contact your system administrator." : "M'a n'oc'h ket o klask stumma un ardivink pe meziant nevez, unan bennak a zo o klask lakaat ac'hanoc'h aotreañ anezho da dizout o roadennoù. M'az eo ze, na gendalc'hit ket, ha kelaouit o merour.",
-    "App token" : "Jedouer meziant",
     "Grant access" : "Reiñ an tremen",
-    "Alternative log in using app token" : "Ur c'hennask disheñvel en ur implij ar jedouer arload",
     "Account access" : "Mont d'ar c'hont",
     "You are about to grant %1$s access to your %2$s account." : "Emaoc'h war-nes reiñ an aotre da \"%1$s\" da dizhout ho kont \"%2$s\".",
     "Account connected" : "Kont kenstaged",
@@ -292,7 +246,6 @@ OC.L10N.register(
     "To avoid timeouts with larger installations, you can instead run the following command from your installation directory:" : "Evit tremen e-biou dale abalamour da ziazezadurioù brasoc'h, e c'hellit implijout an urzh war-lerc’h adalek ho teuliad diazezadur :",
     "Detailed logs" : "Kazetenn munudet",
     "Update needed" : "Un adnevezadur ez eu ezhomp",
-    "Please use the command line updater because you have a big instance with more than 50 users." : "Mar-plij, implijit al linnen-urz adneveziñ peogwir m'az eo brazh o azgoulenn gant muioc'h eget 50 implijer.",
     "For help, see the  <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">documentation</a>." : "Evit kavout skoazel, sellit ouzh an <a target=\"_blank\" rel=\"noreferrer noopener\" href=\"%s\">dielvadur</a>.",
     "I know that if I continue doing the update via web UI has the risk, that the request runs into a timeout and could cause data loss, but I have a backup and know how to restore my instance in case of a failure." : "Gouzout a rañ eo posupl m'a kendalc'hañ an adnevezaden gant web UI, m'az afe va goulenn en un timeout hag e c'hell koll roadennoù, mes ur backup am eus ha gouzout a rañ penaos adkrouiñ va azgoulenn m'a vez c'huitet.",
     "Upgrade via web on my own risk" : "Adnevesaat dre ar web gant va rislkoù d'in me nemetken",
@@ -300,10 +253,58 @@ OC.L10N.register(
     "This %s instance is currently in maintenance mode, which may take a while." : "Adnevesaet a vez %s, pez a kemero sur awalc'h amzer ",
     "This page will refresh itself when the instance is available again." : "Ar bajenn a azgreeno e unan pa vo vak an azgoulenn en dro.",
     "Contact your system administrator if this message persists or appeared unexpectedly." : "Kit e darempred gant anr merour reizhad ma chomm ar c'hemenadenn-mañ, pe ma ze war well dic'hortozet ",
-    "If it is not there ask your local administrator." : "M'a n'eo ket amañ, goulennit o merour lec'h.",
+    "Your web server is not yet properly set up to allow file synchronization, because the WebDAV interface seems to be broken." : "Ho servijour web n'eo ket bet staliet c'hoazh evit aotreañ ar c'hempredañ, peogwir e seblant etrefas WabDAV bezañ torret.",
+    "PHP does not seem to be setup properly to query system environment variables. The test with getenv(\"PATH\") only returns an empty response." : "PHP ne seblant ket bezañ staliet mat evit goulenn d'ar sistem argemennoù endro. An amprouenn gant getenv(\"PATH\") a ro ur respont goullo.",
+    "The read-only config has been enabled. This prevents setting some configurations via the web-interface. Furthermore, the file needs to be made writable manually for every update." : "Aotreet a zo bet ar stumm lenn-nemetken. Ampechiñ a ra cheñch stummoù dre an etrefas-web. Ouzhpenn-se, ar restr en deus ezhomm bezañ adlakaet da  vezañ embannapl dre dorn evit pep adneveziñ.",
+    "Your database does not run with \"READ COMMITTED\" transaction isolation level. This can cause problems when multiple actions are executed in parallel." : "Ho roadennoù-diaz ne droont ket gant al live \"READ COMMITTED\". Kudennoù a zo posupl kaout pa vez graet meur a ober war an dro.",
+    "The PHP module \"fileinfo\" is missing. It is strongly recommended to enable this module to get the best results with MIME type detection." : "N'eus ket eus ar modul PHP \"fileinfo\". Gwelloc'h eo aotreañ ar modul-mañ evit kaout an disoc'hoù gwellañ evit dizoloeiñ ar stumm MIME.",
+    "It was not possible to execute the cron job via CLI. The following technical errors have appeared:" : "Ne oa ket posupl ober al labour Cron dre CLI. Ar gudenn deknikel-mañ a zo deuet war wel :",
+    "The PHP function \"set_time_limit\" is not available. This could result in scripts being halted mid-execution, breaking your installation. Enabling this function is strongly recommended." : "N'eo ket posupl implijout arc’hwel PHP \"set_time_limit\". Galout a ra ar gudenn-se herzel skriptoù e-kreiz o labour, terriñ ar staliadur. Aotreañ an arc'hwel a zo aliet-mat.",
+    "Your PHP does not have FreeType support, resulting in breakage of profile pictures and the settings interface." : "Ho PHP ne zoug ket FreeType, terriñ ar skeudennoù trolinenn ha stummoù an etrefas.",
+    "Missing index \"{indexName}\" in table \"{tableName}\"." : "Ar roll \"{indexName}\" a vank en daolenn \"{tableName}\".",
+    "The database is missing some indexes. Due to the fact that adding indexes on big tables could take some time they were not added automatically. By running \"occ db:add-missing-indices\" those missing indexes could be added manually while the instance keeps running. Once the indexes are added queries to those tables are usually much faster." : "Mankout a ra rollioù er roadenn-diaz. Abalamour e kemer amzer ouzhpennañ rollioù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-indices\" eo posupl ouzhpennañ ar rollioù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ar rollioù ouzhpennet, goulennoù savet d'an taolennoù a vo buanaet.",
+    "Missing optional column \"{columnName}\" in table \"{tableName}\"." : "Ar golonenn diret \"{columnName}\" a vank en daolenn \"{tableName}\".",
+    "The database is missing some optional columns. Due to the fact that adding columns on big tables could take some time they were not added automatically when they can be optional. By running \"occ db:add-missing-columns\" those missing columns could be added manually while the instance keeps running. Once the columns are added some features might improve responsiveness or usability." : "Mankout a ra kolonennoù er roadennoù-diaz dibabapl. Abalamour e kemer amzer ouzhpennañ kolonennoù e taolennoù bras, n'int ket bet lakaet en un doare otomatek. En ul lakaat da dreiñ \"occ db:add-missing-columns\" eo posupl ouzhpennañ ar c'holonennoù a vank gant an dorn pa vo an azgoulenn o treiñ. Ur wech ouzhpennet ar c'holonennoù, goulennoù savet d'an taolennoù a vo buanaet.",
+    "This instance is missing some recommended PHP modules. For improved performance and better compatibility it is highly recommended to install them." : "An etrefas a vank dezhañ moduloù PHP aliet. Evit gwellaat ar mont en dro hag ar c'heverlec’hded ez eo kinniget kenañ o staliañ.",
+    "SQLite is currently being used as the backend database. For larger installations we recommend that you switch to a different database backend." : "SQLite a vez implijet evel ur backend ar roadenoù-diaz. Evit staliadurioù brasoc'h e vez aliet cheñch d'ur backend roadennoù-diaz all.",
+    "This is particularly recommended when using the desktop client for file synchronisation." : "Kinniget kennañ pa vez implijet ar c'hliant burev evit kempredañ ar restroù.",
+    "The PHP memory limit is below the recommended value of 512MB." : "Bevenn memor PHP a zo dindan an hini kinniget eus 512MB.",
+    "Some app directories are owned by a different user than the web server one. This may be the case if apps have been installed manually. Check the permissions of the following app directories:" : "Touliadoù meziant zo a zo dalc'het gant un implijour diseñvel eus ar servijour web. M'az eo bet stalied ar meziant gant an dorn eo normal. Gwiriit an aotreoù an teuliadoù meziant mañ:",
+    "This instance uses an S3 based object store as primary storage. The uploaded files are stored temporarily on the server and thus it is recommended to have 50 GB of free space available in the temp directory of PHP. Check the logs for full details about the path and the available space. To improve this please change the temporary directory in the php.ini or make more space available in that path." : "An azgoulenn a implij  un dra diazezed war S3 evel e bern pennañ. Ar restroù pellkaset a vez  bernied ebit point war ar servijour, setut perak eo kinniget kaout 50 GB plass dieub e teuliad PHP temp. Gwiriit ar gazetenn evit munudoù an hent hag ar plass dieub. Evit gwellat ar blass, cheñchit an teuliad amzeriel e-barzh php.ini pa roit muioc'h a blass en hent.",
+    "The \"{header}\" HTTP header is not set to \"{expected}\". This is a potential security or privacy risk, as it is recommended to adjust this setting accordingly." : "Penn HTTP \"{header}\" n'eo ket stumm \"{expected}\". Posuple eo bezha ur gudenn surentez pe prevezted, kinniget eo cheñch ar stumm mañ.",
+    "The \"{header}\" HTTP header is not set to \"{expected}\". Some features might not work correctly, as it is recommended to adjust this setting accordingly." : "Penn HTTP \"{header}\" n'eo ket stumm \"{expected}\". Perzhioù zo na labouro ket mat, kinniget eo cheñch ar stumm mañ.",
+    "Wrong username or password." : "Anv-implijader pe ger-tremen direizh",
+    "User disabled" : "Implijer disaotreet",
+    "Username or email" : "Anv implijer pe bostel",
     "Settings" : "Arventennoù",
-    "File not found" : "N'eo ket bet kavet ar restr",
-    "The document could not be found on the server. Maybe the share was deleted or has expired?" : "N'eo ket posuple kavout ar ragtress war ar servijour. Marteze eo re gozh pe ez eo bet lammet ar rannadenn.",
-    "Please use the command line updater because automatic updating is disabled in the config.php." : "Mar-plij, implijit al linenn-urzh adneveziñ peogwir eo disaotreet an adneveziñ otomatek e-barzh config.php."
+    "Show all contacts …" : "Diskwel tout an darempredoù ...",
+    "No files in here" : "Restr ebet amañ",
+    "New folder" : "Heuliad nevez",
+    "No more subfolders in here" : "N'ez eus ket isteuliadoù all amañ",
+    "Name" : "Anv",
+    "Size" : "Ment",
+    "Modified" : "Cheñchet",
+    "\"{name}\" is an invalid file name." : "N'eo ket \"{name}\" un anv restr aotreet.",
+    "File name cannot be empty." : "N'hall ket anv ur restr bezañ goullo.",
+    "\"/\" is not allowed inside a file name." : "N'eo ket aotreet \"/\" e anv ur restr.",
+    "\"{name}\" is not an allowed filetype" : "N'eo ket \"{name}\" un doare restr aotreet",
+    "{newName} already exists" : "{newName} zo anezhañ c'hoazh",
+    "Error loading file picker template: {error}" : "Ur fazi a zo bet en ur c'hargañ ar choazer eskelet restr : {error}",
+    "Error loading message template: {error}" : "Ur fazi zo bet pa voe karget stumm skouer ar gemenadenn : [error]",
+    "Pending" : "O c'hortoz",
+    "Home" : "Degemer",
+    "Copy to {folder}" : "Eilan e {folder}",
+    "Move to {folder}" : "Diblasañ da {folder}",
+    "Authentication required" : "Eus un dilesa ez eus ezhomp",
+    "This action requires you to confirm your password" : "An ober-mañ a c'houlenn e kadarnfec'h ho ker-tremen",
+    "Confirm" : "Kadarnañ",
+    "Failed to authenticate, try again" : "Dilesa c'hwitet, klaskit en dro",
+    "Users" : "Implijer",
+    "Username" : "anv implijer",
+    "Database user" : "Roadennoù-diaz an implijourien",
+    "Confirm your password" : "Kadarnañ ho ker-tremen",
+    "App token" : "Jedouer meziant",
+    "Alternative log in using app token" : "Ur c'hennask disheñvel en ur implij ar jedouer arload",
+    "Please use the command line updater because you have a big instance with more than 50 users." : "Mar-plij, implijit al linnen-urz adneveziñ peogwir m'az eo brazh o azgoulenn gant muioc'h eget 50 implijer."
 },
 "nplurals=5; plural=((n%10 == 1) && (n%100 != 11) && (n%100 !=71) && (n%100 !=91) ? 0 :(n%10 == 2) && (n%100 != 12) && (n%100 !=72) && (n%100 !=92) ? 1 :(n%10 ==3 || n%10==4 || n%10==9) && (n%100 < 10 || n% 100 > 19) && (n%100 < 70 || n%100 > 79) && (n%100 < 90 || n%100 > 99) ? 2 :(n != 0 && n % 1000000 == 0) ? 3 : 4);");
