@@ -6,13 +6,13 @@ OC.L10N.register(
     "But, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it." : "ولكن، إذا كنت تُفضّل الاحتفاظ بملف config.php للقراءة فقط، فعيّن الخيار \"config_is_read_only\" إلى \"صح\" \"True\".",
     "See %s" : "أنظر%s",
     "Application %1$s is not present or has a non-compatible version with this server. Please check the apps directory." : "التطبيق %1$s غير موجود أو ليس له إصدار متطابق مع هذا الخادوم. رجاءً، راجع دليل التطبيقات apps directory.",
-    "Sample configuration detected" : "تمّ العثور على عيّنة إعدادات sample configuration.",
+    "Sample configuration detected" : "تمّ العثور على عيّنة إعدادات.",
     "It has been detected that the sample configuration has been copied. This can break your installation and is unsupported. Please read the documentation before performing changes on config.php" : "تمّ اكتشاف أن عيّنة الإعدادات قد تمّ نسخها. يُمكن لهذا أن يُعطّل عملية التنصيب و هو أمر غير مدعوم. نرجو الاطلاع على التعليمات الواردة في وثائق النظام قبل إحداث أي تعديلات على ملف config.php",
     "The page could not be found on the server." : "تعذّر العثور على الصفحة في الخادوم",
     "%s email verification" : "%s التحقّق من الإيميل",
     "Email verification" : "التحقّق من الإيميل",
-    "Click the following button to confirm your email." : "إضغط الزر التالي لتوكيد الإيميل",
-    "Click the following link to confirm your email." : "إضغط الرابط التالي لتوكيد الإيميل",
+    "Click the following button to confirm your email." : "إضغط الزر التالي لتأكيد الإيميل",
+    "Click the following link to confirm your email." : "إضغط الرابط التالي لتأكيد الإيميل",
     "Confirm your email" : "قم بتأكيد إيميلك",
     "Other activities" : "حركات أخرى",
     "%1$s and %2$s" : "%1$s و %2$s",
@@ -21,9 +21,10 @@ OC.L10N.register(
     "%1$s, %2$s, %3$s, %4$s and %5$s" : "%1$s، %2$s، %3$s، %4$s و %5$s",
     "Education Edition" : "الإصدار التعليمي",
     "Enterprise bundle" : "حزمة المؤسسة",
-    "Groupware bundle" : "حزمة أدوات العمل الجماعي Groupware",
+    "Groupware bundle" : "حزمة أدوات العمل الجماعي",
     "Hub bundle" : "حزمة الـ\"هَبْ\" Hub",
-    "Social sharing bundle" : "حزمة المشاركة الاجتماعية Social Sharing",
+    "Public sector bundle" : "حزمة القطاع العام",
+    "Social sharing bundle" : "حزمة المشاركة الاجتماعية",
     "PHP %s or higher is required." : "إصدار PHP %s أو أحدث منه مطلوب.",
     "PHP with a version lower than %s is required." : "PHP الإصدار %s أو أقل مطلوب.",
     "%sbit or higher PHP required." : "مكتبات PHP ذات %s بت أو أعلى مطلوبة.",
@@ -36,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "المنصّات التالية مدعومة: %s",
     "Server version %s or higher is required." : "مطلوب إصدار الخادم %s أو أعلى.",
     "Server version %s or lower is required." : "مطلوب إصدار الخادم %s أو أقل.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
-    "Logged in user must be an admin or sub admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin.",
-    "Logged in user must be an admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin.",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً أو يملك حقاً خاصاً للوصول إلى هذا الإعداد",
+    "Logged in account must be an admin or sub admin" : "الداخل للحساب يجب أن يكون مُشرفاً أو مشرفاً فرعيّاً ",
+    "Logged in account must be an admin" : "الداخل للحساب يجب أن يكون مُشرفاً ",
     "Wiping of device %s has started" : "بدأ مسح الجهاز %s ",
     "Wiping of device »%s« has started" : "بدأ مسح الجهاز »%s« ",
     "»%s« started remote wipe" : "»%s« بدأ المسح عن بُعدٍ",
@@ -71,7 +72,7 @@ OC.L10N.register(
     "last year" : "السنةالماضية",
     "_in %n year_::_in %n years_" : ["في %n أعوام","في %nعام","في %nأعوام","في %nأعوام","في %n أعوام","في %nأعوام"],
     "_%n year ago_::_%n years ago_" : ["%n منذ سنوات","%n منذ سنة","%n منذ سنوات","%n منذ سنوات","%n منذ سنوات","%n منذ سنوات"],
-    "_in %n hour_::_in %n hours_" : ["في %nساعات","في %nساعة","في %nساعات","في %nساعات","في %n ساعات","في %n ساعات"],
+    "_in %n hour_::_in %n hours_" : ["في %nساعات","في %nساعة","في %n ساعات","في %n ساعات","في %n ساعات","في %n ساعات"],
     "_%n hour ago_::_%n hours ago_" : ["%n منذ ساعات","%n منذ ساعة","%n منذ ساعات","%n منذ ساعات","%n منذ ساعات","%n منذ ساعات"],
     "_in %n minute_::_in %n minutes_" : ["في %nدقائق","في %nدقيقة","في %nدقائق","في %nدقائق","في %nدقائق","في %nدقائق"],
     "_%n minute ago_::_%n minutes ago_" : ["%n منذ دقائق","%n منذ دقيقة","%n منذ دقائق","%n منذ دقائق","%n منذ دقائق","%n منذ دقائق"],
@@ -92,8 +93,8 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "لا يمكن تثبيت التطبيق \"%s\" لأنه غير متوافق مع هذا الإصدار من الخادم.",
     "__language_name__" : "اللغة العربية",
     "This is an automatically sent email, please do not reply." : "هذه رسالة آلية، يرجى عدم الرد عليها.",
-    "Help" : "المساعدة",
-    "Appearance and accessibility" : "المظهر appearance، و سهولة الوصول accessibility",
+    "Help & privacy" : "المساعدة و الخصوصية",
+    "Appearance and accessibility" : "المظهر  و سهولة الوصول.",
     "Apps" : "التطبيقات",
     "Personal settings" : "إعدادات شخصيّة",
     "Administration settings" : "إعدادات الإدارة",
@@ -103,11 +104,11 @@ OC.L10N.register(
     "Email" : "البريد الإلكتروني",
     "Mail %s" : "بريد %s",
     "Fediverse" : "الشبكة اللامركزية للتواصل الاجتماعي \"فيديفيرس\" Fediverse",
-    "View %s on the fediverse" : "عرض %s على الفيديفيرس Fediverse",
+    "View %s on the fediverse" : "عرض %s على الفيديفيرس.",
     "Phone" : "الهاتف",
     "Call %s" : "إتصل بـ%s",
     "Twitter" : "تويتر",
-    "View %s on Twitter" : "عرض %s على تويتر Twitter",
+    "View %s on Twitter" : "عرض %s على تويتر.",
     "Website" : "موقع الويب",
     "Visit %s" : "زيارة %s",
     "Address" : "العنوان",
@@ -117,24 +118,24 @@ OC.L10N.register(
     "Headline" : "عنوان ",
     "Organisation" : "مؤسسة",
     "Role" : "الدور",
-    "Unknown user" : "المستخدم غير معروف",
+    "Unknown account" : "حساب غير معروف",
     "Additional settings" : "الإعدادات المتقدمة",
-    "Enter the database username and name for %s" : "أدخل اسم المستخدم لقاعدة البيانات و اسم %s",
-    "Enter the database username for %s" : "أدخل اسم المستخدم لقاعدة البيانات لـ %s",
+    "Enter the database Login and name for %s" : "أدخِل مُعرف تسجيل الدخول و الاسم الخاص بقاعدة البيانات %s",
+    "Enter the database Login for %s" : "أدخِل مُعرف تسجيل الدخول قاعدة البيانات لـ %s",
     "Enter the database name for %s" : "أدخل اسم قاعدة البيانات لـ%s",
     "You cannot use dots in the database name %s" : "لا يمكنك استخدام النقاط dots في اسم قاعدة البيانات %s",
-    "MySQL username and/or password not valid" : "اسم المستخدم لقاعدة البيانات MySQL و/أو كلمة المرور غير صحيحة",
+    "MySQL Login and/or password not valid" : "مُعرف تسجل الدخول او كلمة مرور MySQL غير صحيحة",
     "You need to enter details of an existing account." : "يلزمك إدخال تفاصيل حسابك الحالي.",
     "Oracle connection could not be established" : "لم تنجح محاولة اتصال Oracle",
-    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
-    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
-    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك الإصدار X غير مدعوم و %s لن يعمل بشكل صحيح على هذه المنصة.  استخدمه على مسؤوليتك!",
+    "Oracle Login and/or password not valid" : "مُعرف تسجيل الدخول او كلمة مرور Oracle غير صحيحة",
+    "PostgreSQL Login and/or password not valid" : "مُعرف تسجيل دخول او كلمة مرور PostgreSQL غير صحيحة",
+    "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "نظام ماك العاشر غير مدعوم و %s .لن يعمل بالشكل الصحيح على هذه المنصةاستعمله يكون على مسؤوليتك!",
     "For the best results, please consider using a GNU/Linux server instead." : "فضلاً ضع في الاعتبار استخدام نظام GNU/Linux بدل الأنظمة الأخرى للحصول على أفضل النتائج.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "يبدو أن كائن %s يعمل على بيئة PHP 32-Bit  وكذلك تم تكوين open_basedir في ملف php.ini. يؤدي ذلك إلى مشاكل مع الملفات التي يزيد حجمها عن 4 غيغابايت ولا يُنصح بذلك بشدة.",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "فضلاً إحذف إعداد open_basedir من ملف php.ini لديك أو حوّل إلى PHP إصدار 64 بت.",
-    "Set an admin username." : "اعداد اسم مستخدم للمدير",
-    "Set an admin password." : "تعيين كلمة مرور للمدير",
-    "Cannot create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في  data directory دليل البيانات %s",
+    "Set an admin Login." : "تعيين مُعرف تسجيل دخول المشرف.",
+    "Set an admin password." : "تعيين كلمة مرور للمشرف",
+    "Cannot create or write into the data directory %s" : "لا يمكن الإنشاء أو الكتابة في دليل البيانات %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "يجب أن تقوم الواجهة الخلفية للمشاركة (Sharing backend) %s بتطبيق الواجهة OCP\\Share_Backend",
     "Sharing backend %s not found" : "لم يتم العثور على الواجهة الخلفية (Sharing backend)  %s",
     "Sharing backend for %s not found" : "مشاركة الخلفية لـ %s غير موجود",
@@ -150,7 +151,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "تاريخ انتهاء الصلاحية غير صالح.  التاريخ المحدد في الماضي!",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر من %n أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر من %n يوم في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل","لا يمكن تعيين تاريخ انتهاء الصلاحية لأكثر %n من أيام في المستقبل"],
     "Sharing is only allowed with group members" : "المشاركة مسموحة فقط مع أعضاء المجموعة",
-    "Sharing %s failed, because this item is already shared with user %s" : "المشاركة %sلم تتم لأن هذا العنصر سبقت مشاركته سلفاً مع المستخدم %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "فشلت مشاركة %s؛ لأن هذا العنصر سبقت مشاركته مع الحساب %s",
     "%1$s shared »%2$s« with you" : "%1$s شارك »%2$s« معك",
     "%1$s shared »%2$s« with you." : "%1$s شَارَكَ »%2$s« معك.",
     "Click the button below to open it." : "أنقر على الزر أدناه لفتحه.",
@@ -179,40 +180,40 @@ OC.L10N.register(
     "Th" : "خم",
     "Fr" : "جم",
     "Sa" : "سب",
-    "January" : "جانفي",
-    "February" : "فيفري",
+    "January" : "يناير",
+    "February" : "فبراير",
     "March" : "مارس",
-    "April" : "أفريل",
-    "May" : "ماي",
-    "June" : "جوان",
-    "July" : "جويلية",
-    "August" : "أوت",
+    "April" : "أبريل",
+    "May" : "مايو",
+    "June" : "يونيو",
+    "July" : "يوليو",
+    "August" : "اغسطس",
     "September" : "سبتمبر",
     "October" : "أكتوبر",
     "November" : "نوفمبر",
     "December" : "ديسمبر",
-    "Jan." : "جان.",
-    "Feb." : "فيف.",
+    "Jan." : "ينا.",
+    "Feb." : "فبر.",
     "Mar." : "مار.",
-    "Apr." : "أفر.",
+    "Apr." : "أبر.",
     "May." : "ماي",
-    "Jun." : "جوا.",
-    "Jul." : "جوي.",
+    "Jun." : "بون.",
+    "Jul." : "يول.",
     "Aug." : "أوت",
     "Sep." : "سبت.",
     "Oct." : "أكت.",
     "Nov." : "نوف.",
     "Dec." : "ديس.",
     "A valid password must be provided" : "يجب ادخال كلمة مرور صحيحة",
-    "The username is already being used" : "اسم المستخدم قيد الاستخدام بالفعل",
-    "Could not create user" : "لا يمكن إنشاء المستخدم",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الحروف التالية فقط مسموحٌ بها في اسم المستخدِم: \"a-z\"و \"A-Z\"و \"0-9\" و الفراغ و  \"_.@-'\"",
-    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
-    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
-    "Username must not consist of dots only" : "اسم المستخدم يجب ألاّ يتكون من نقاطٍ dots فقط",
-    "Username is invalid because files already exist for this user" : "اسم المستخدم غير صحيحٍ لأن هنالك ملفات موجودة سلفاً لهذا المستخدم",
-    "User disabled" : "المستخدم معطّل",
-    "Login canceled by app" : "تم إلغاء الدخول مِن طرف التطبيق",
+    "The Login is already being used" : "تسجيل الدخول قيد الاستعمال بالفعل",
+    "Could not create account" : "تعذّر إنشاء الحساب",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الأحرف التالية فقط مسموح باستعمالها في مُعرف تسجيل الدخول:  \"a-z\" و , و \"A-Z\"، و \"0-9\", و المسافة، و \"_.@-'\"",
+    "A valid Login must be provided" : "يجب إعطاء مُعرف تسجيل الدخول الصحيح",
+    "Login contains whitespace at the beginning or at the end" : "مُعرف تسجيل الدخول يحتوي مسافات بيضاء في بدايتها أو في نهايتها",
+    "Login must not consist of dots only" : "يجب ألّا يكون مُعرف تسجيل الدخول يحتوي فقط على نُقَطٍ",
+    "Login is invalid because files already exist for this user" : "مُعرف تسجيل الدخول غير صحيح لأن هنالك ملفات موجودة مسبقاً لهذا المستخدِم",
+    "Account disabled" : "الحساب مُعطَّل",
+    "Login canceled by app" : "تم إلغاء تسجيل الدخول مِن طرف التطبيق",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "التطبيق \"%1$s\" لا يمكن تنصيبه بسبب أن التبعيّات التالية لم تتحقق: %2$s",
     "a safe home for all your data" : "المكان الآمن لجميع بياناتك",
     "File is currently busy, please try again later" : "إنّ الملف مشغول الآمن، يرجى إعادة المحاولة لاحقًا",
@@ -225,8 +226,8 @@ OC.L10N.register(
     "This can usually be fixed by giving the web server write access to the config directory. See %s" : "يمكن إصلاح هذا عادةً بمنح خادوم الوب صلاحية الوصول إلى الدليل \"config\". للمزيد، أنظر: %s",
     "Or, if you prefer to keep config.php file read only, set the option \"config_is_read_only\" to true in it. See %s" : "و إذا كنت تُفضّل بقاء الملف \"config.php\" للقراءة فقط، عيّن الخيار  \"config_is_read_only\". أنظر: %s",
     "Cannot write into \"apps\" directory." : "لا يمكن الكتابة في الدليل \"apps\".",
-    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في دليل التطبيقات apps dicrectory أو تعطيل متجر التطبيقات App store في الملف config.",
-    "Cannot create \"data\" directory." : "لا يمكن إنشاء دليل data directory.",
+    "This can usually be fixed by giving the web server write access to the apps directory or disabling the App Store in the config file." : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في دليل التطبيقات في الملف او تعطيل متجر تطبيقات ابل في ملف \"config\".",
+    "Cannot create \"data\" directory." : "لا يمكن إنشاء ملف بيانات",
     "This can usually be fixed by giving the web server write access to the root directory. See %s" : "يمكن إصلاح ذلك عادةً عن طريق منح خادم الويب حق الكتابة في الدليل الجذري root directory.  أنطر:%s",
     "Permissions can usually be fixed by giving the web server write access to the root directory. See %s." : "الأذونات يمكن إصلاحها عادةً عن طريق منح خادم الويب حق الكتابة في الدليل الجذري root directory. أنظر:%s.",
     "Your data directory is not writable." : "دليل البيانات data directory لا يمكن الكتابة فيه.",
@@ -244,8 +245,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "يرجى مطالبة مسؤول الخادم بإعادة تشغيل خادم الويب.",
     "The required %s config variable is not configured in the config.php file." : "مُتغيّر التهيئة %s المطلوب لم تتم تهيئته في الملف config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "رجاءً، أطلب من مشرف نظامك مراجعة تهيئة نكست كلاود Nextcloud configuration.",
-    "Your data directory is readable by other users." : "دليل بياناتك data directory يُمكن قراءته من مستخدمين آخرين.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "الرجاء تغيير الصلاحيات إلى 0770 حتى لا يتمكن المستخدمون الآخرون من عرض محتويات المجلد.",
+    "Your data directory is readable by other people." : "دليل بياناتك مسموحٌ بقراءته من قِبَل أشخاص آخرين.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "قُم رجاءً بتغيير الأذونات إلى 0770 حتى لا يتسنّى لأشخاص آخرين استعراض الدليل.",
     "Your data directory must be an absolute path." : "مسار دليل بياناتك data directory يجب أن يكون مساراً مُطلقاً absolute path.",
     "Check the value of \"datadirectory\" in your configuration." : "راجع قيمة \"datadirectory\" في تهيئتك.",
     "Your data directory is invalid." : "دليل بياناتك data directory غير صحيح.",
@@ -269,12 +270,30 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "يُلَخِّص النص بتقليل طوله دون فقدان المعنى.",
     "Extract topics" : "إستخلاص الموضوعات",
     "Extracts topics from a text and outputs them separated by commas." : "يستخلص المواضيع من النص و إخراجها مفصولة بفواصل.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "ملفات التطبيق %1$s لم يتم استبدالها مؤخّراً. تأكد من تطابق إصدارها مع الخادوم.",
-    "404" : "404",
-    "Full name" : "الاسم الكامل",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "نحتاج النسخة 2.7.0 من libxml2 على الأقل. النسخة المتوافرة حالياً هي %s",
-    "To fix this issue update your libxml2 version and restart your web server." : "لإصلاح هذه المشكلة، قم بتحديث إصدار libxml2 الخاص بك وأعد تشغيل خادم الويب.",
+    "404" : "لم يتم العثور على الصفحة خطأ عدد 404",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin، أو يحمل صلاحياتٍ خاصّةٍ للوصول إلى هذه الإعدادات.",
+    "Logged in user must be an admin or sub admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin، أو مُشرفاً فرعيّاً sub admin.",
+    "Logged in user must be an admin" : "المستخدم الداخل يجب أن يكون مُشرفاً admin.",
+    "Help" : "المساعدة",
+    "Unknown user" : "المستخدم غير معروف",
+    "Enter the database username and name for %s" : "أدخل اسم المستخدم و اسم قاعدة البيانات %s",
+    "Enter the database username for %s" : "أدخل اسم المستخدم لقاعدة البيانات لـ %s",
+    "MySQL username and/or password not valid" : "اسم المستخدم لقاعدة البيانات MySQL و/أو كلمة المرور غير صحيحة",
+    "Oracle username and/or password not valid" : "اسم المستخدم  و/أو  كلمة المرور لنظام Oracle غير صحيح",
+    "PostgreSQL username and/or password not valid" : "اسم المستخدم / أو كلمة المرور الخاصة بـPostgreSQL غير صحيحة",
+    "Set an admin username." : "اعداد اسم مستخدم المشرف",
+    "Sharing %s failed, because this item is already shared with user %s" : "المشاركة %sلم تتم لأن هذا العنصر سبقت مشاركته سلفاً مع المستخدم %s",
+    "The username is already being used" : "اسم المستخدم قيد الاستخدام بالفعل",
+    "Could not create user" : "لا يمكن إنشاء المستخدم",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "الحروف التالية فقط مسموحٌ بها في اسم المستخدِم: \"a-z\"و \"A-Z\"و \"0-9\" و الفراغ و  \"_.@-'\"",
+    "A valid username must be provided" : "يجب ادخال اسم مستخدم صحيح",
+    "Username contains whitespace at the beginning or at the end" : "إنّ إسم المستخدم يحتوي على مسافة بيضاء سواءا في البداية أو النهاية",
+    "Username must not consist of dots only" : "اسم المستخدم يجب ألاّ يتكون من نقاطٍ dots فقط",
+    "Username is invalid because files already exist for this user" : "اسم المستخدم غير صحيحٍ لأن هنالك ملفات موجودة سلفاً لهذا المستخدم",
+    "User disabled" : "المستخدم معطّل",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 مطلوبة.",
-    "Please upgrade your database version." : "رجاءً، قم بترقية إصدار قاعدة بياناتك."
+    "Please upgrade your database version." : "رجاءً، قم بترقية إصدار قاعدة بياناتك.",
+    "Your data directory is readable by other users." : "دليل بياناتك data directory يُمكن قراءته من مستخدمين آخرين.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "الرجاء تغيير الصلاحيات إلى 0770 حتى لا يتمكن المستخدمون الآخرون من عرض محتويات المجلد."
 },
 "nplurals=6; plural=n==0 ? 0 : n==1 ? 1 : n==2 ? 2 : n%100>=3 && n%100<=10 ? 3 : n%100>=11 && n%100<=99 ? 4 : 5;");
