@@ -14,7 +14,7 @@ OC.L10N.register(
     "Click the following button to confirm your email." : "Click the following button to confirm your email.",
     "Click the following link to confirm your email." : "Click the following link to confirm your email.",
     "Confirm your email" : "Confirm your email",
-    "Other activities" : "Other activities",
+    "Other activities" : "سایر فعالیت ها",
     "%1$s and %2$s" : "%1$sو%2$s",
     "%1$s, %2$s and %3$s" : "%1$s،%2$sو%3$s",
     "%1$s, %2$s, %3$s and %4$s" : "%1$s،%2$s،%3$sو%4$s",
@@ -36,9 +36,6 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "بن‌سازه‌های زیر پشتیبانی می‌شوند: %s",
     "Server version %s or higher is required." : "نیاز به کارساز با نگارش %s یا بالاتر.",
     "Server version %s or lower is required." : "نیاز به کارساز با نگارش %s یا پایین‌تر.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Logged in user must be an admin, a sub admin or gotten special right to access this setting",
-    "Logged in user must be an admin or sub admin" : "ورود به سیستم کاربر باید یک مدیر یا مدیر فرعی باشد",
-    "Logged in user must be an admin" : "ورود به سیستم کاربر باید مدیر سایت باشد",
     "Wiping of device %s has started" : "پاک کردن دستگاه%s شروع شده است",
     "Wiping of device »%s« has started" : "پاک کردن دستگاه%s شروع شده است",
     "»%s« started remote wipe" : "%sپاک کردن از راه دور",
@@ -92,7 +89,6 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "کارهٔ «%s» به دلیل سازگار نبودن با این نگارش از کارساز نمی‌تواند نصب شود.",
     "__language_name__" : "فارسى",
     "This is an automatically sent email, please do not reply." : "این یک رایانامهٔ خودکار است. لطفاً پاسخ ندهید.",
-    "Help" : "راه‌نما",
     "Appearance and accessibility" : "ظاهر و دسترسی‌پذیری",
     "Apps" : "  برنامه ها",
     "Personal settings" : "تنظیمات شخصی",
@@ -117,22 +113,15 @@ OC.L10N.register(
     "Headline" : "عنوان",
     "Organisation" : "سازمان",
     "Role" : "نقش",
-    "Unknown user" : "کاربر نامعلوم",
     "Additional settings" : "تنظیمات اضافی",
-    "Enter the database username and name for %s" : "ورود نام و نام کاربری پایگاه داده برای %s",
-    "Enter the database username for %s" : "ورود نام کاربری پایگاه داده برای %s",
     "Enter the database name for %s" : "ورود نام پایگاه داده برای %s",
     "You cannot use dots in the database name %s" : "نمی‌توانید در در نام پایگاه دادهٔ %s از نقطه استفاده کنید",
-    "MySQL username and/or password not valid" : "نام کاربری یا گذرواژهٔ مای‌سکول معتبر نیست",
     "You need to enter details of an existing account." : "لازم است جزییات یک حساب موحود را وارد کنید.",
     "Oracle connection could not be established" : "ارتباط اراکل نمیتواند برقرار باشد.",
-    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "مک‌اواس ۱۰ پشتیبانی نشده و %s روی این بن‌سازه درست کار نخواهد کرد. با مسئولیت خودتان استفاده کنید!",
     "For the best results, please consider using a GNU/Linux server instead." : "برای بهترین نتیجه، استفاده از یک کارساز گنو/لینوکسی را در نظر داشته باشید.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "به نظر می رسد%s که این نمونه در یک محیط PHP 32 بیتی در حال اجرا است و open_baseir در php.ini پیکربندی شده است. این مسئله به پرونده هایی با بیش از 4 گیگ منجر می شود و بسیار دلسرد می شود",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "لطفاً تنظیمات open_baseir را درون php.ini خود حذف کنید یا به PHP 64 بیتی تغییر دهید.",
-    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
     "Set an admin password." : "یک رمزعبور برای مدیر تنظیم نمایید.",
     "Cannot create or write into the data directory %s" : "Cannot create or write into the data directory %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "به اشتراک گذاشتن باطن باید رابط OCP \\ Share_Backend %sرا پیاده سازی کند",
@@ -150,7 +139,6 @@ OC.L10N.register(
     "Expiration date is in the past" : "تاریخ انقضا در گذشته است",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Cannot set expiration date more than %n day in the future","Cannot set expiration date more than %n days in the future"],
     "Sharing is only allowed with group members" : "Sharing is only allowed with group members",
-    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
     "%1$s shared »%2$s« with you" : "%1$s به اشتراک گذاشته » %2$s« با شما",
     "%1$s shared »%2$s« with you." : "%1$s به اشتراک گذاشته » %2$s« با شما",
     "Click the button below to open it." : "برای باز کردن آن روی دکمه زیر کلیک کنید.",
@@ -203,14 +191,6 @@ OC.L10N.register(
     "Nov." : "نو.",
     "Dec." : "دس.",
     "A valid password must be provided" : "رمز عبور صحیح باید وارد شود",
-    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
-    "Could not create user" : "نتواسنت کاربر را ایجاد کند",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"",
-    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
-    "Username contains whitespace at the beginning or at the end" : "نام کاربری دارای فضای سفید در ابتدا یا انتهای آن است",
-    "Username must not consist of dots only" : "نام کاربری نباید فقط از نقاط تشکیل شده باشد",
-    "Username is invalid because files already exist for this user" : "Username is invalid because files already exist for this user",
-    "User disabled" : "کاربر از کار افتاده",
     "Login canceled by app" : "ورود به دست کاره لغو شد",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "کارهٔ «%1$s» نمی‌تواند نصب شود؛ چرا که وابستگی زیر تأمین نشده: %2$s",
     "a safe home for all your data" : "خانه‌ای امن برای تمامی داده‌هایتان",
@@ -243,8 +223,6 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "لطفاً از سرور سرور خود بخواهید که وب سرور را مجدداً راه اندازی کند.",
     "The required %s config variable is not configured in the config.php file." : "The required %s config variable is not configured in the config.php file.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Please ask your server administrator to check the Nextcloud configuration.",
-    "Your data directory is readable by other users." : "Your data directory is readable by other users.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "لطفاً مجوزها را به 0770 تغییر دهید تا فهرست توسط سایر کاربران فهرست نشود.",
     "Your data directory must be an absolute path." : "Your data directory must be an absolute path.",
     "Check the value of \"datadirectory\" in your configuration." : "Check the value of \"datadirectory\" in your configuration.",
     "Your data directory is invalid." : "Your data directory is invalid.",
@@ -268,12 +246,30 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Summarizes text by reducing its length without losing key information.",
     "Extract topics" : "Extract topics",
     "Extracts topics from a text and outputs them separated by commas." : "Extracts topics from a text and outputs them separated by commas.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "فایل های برنامه %1$sبه درستی تعویض نشد. اطمینان حاصل کنید که این یک نسخه سازگار با سرور است.",
     "404" : "۴۰۴",
-    "Full name" : "نام کامل",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 حداقل مورد نیاز است. در حال حاضر %sنصب شده است",
-    "To fix this issue update your libxml2 version and restart your web server." : "برای رفع این مشکل نسخه libxml2 خود را به روز کنید و سرور وب خود را مجدداً راه اندازی کنید.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Logged in user must be an admin, a sub admin or gotten special right to access this setting",
+    "Logged in user must be an admin or sub admin" : "ورود به سیستم کاربر باید یک مدیر یا مدیر فرعی باشد",
+    "Logged in user must be an admin" : "ورود به سیستم کاربر باید مدیر سایت باشد",
+    "Help" : "راه‌نما",
+    "Unknown user" : "کاربر نامعلوم",
+    "Enter the database username and name for %s" : "ورود نام و نام کاربری پایگاه داده برای %s",
+    "Enter the database username for %s" : "ورود نام کاربری پایگاه داده برای %s",
+    "MySQL username and/or password not valid" : "نام کاربری یا گذرواژهٔ مای‌سکول معتبر نیست",
+    "Oracle username and/or password not valid" : "نام کاربری و / یا رمزعبور اراکل معتبر نیست.",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL نام کاربری و / یا رمزعبور معتبر نیست.",
+    "Set an admin username." : "یک نام کاربری برای مدیر تنظیم نمایید.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Sharing %s failed, because this item is already shared with user %s",
+    "The username is already being used" : "نام‌کاربری قبلا استفاده شده است",
+    "Could not create user" : "نتواسنت کاربر را ایجاد کند",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"",
+    "A valid username must be provided" : "نام کاربری صحیح باید وارد شود",
+    "Username contains whitespace at the beginning or at the end" : "نام کاربری دارای فضای سفید در ابتدا یا انتهای آن است",
+    "Username must not consist of dots only" : "نام کاربری نباید فقط از نقاط تشکیل شده باشد",
+    "Username is invalid because files already exist for this user" : "Username is invalid because files already exist for this user",
+    "User disabled" : "کاربر از کار افتاده",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 required.",
-    "Please upgrade your database version." : "Please upgrade your database version."
+    "Please upgrade your database version." : "Please upgrade your database version.",
+    "Your data directory is readable by other users." : "Your data directory is readable by other users.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "لطفاً مجوزها را به 0770 تغییر دهید تا فهرست توسط سایر کاربران فهرست نشود."
 },
 "nplurals=2; plural=(n > 1);");
