@@ -23,6 +23,7 @@ OC.L10N.register(
     "Enterprise bundle" : "Företagspaketet",
     "Groupware bundle" : "Gruppvarupaket",
     "Hub bundle" : "Hub-paket",
+    "Public sector bundle" : "Paket för offentlig sektor",
     "Social sharing bundle" : "Kommunikationspaket",
     "PHP %s or higher is required." : "PHP %s eller högre krävs.",
     "PHP with a version lower than %s is required." : "PHP med version lägre än %s krävs.",
@@ -36,9 +37,9 @@ OC.L10N.register(
     "The following platforms are supported: %s" : "Följande plattformar stöds: %s",
     "Server version %s or higher is required." : "Serverversion %s eller nyare krävs.",
     "Server version %s or lower is required." : "Serverversion %s eller äldre krävs.",
-    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Inloggad användare måste vara en admin, sub-admin eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
-    "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
-    "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
+    "Logged in account must be an admin, a sub admin or gotten special right to access this setting" : "Inloggat konto måste vara en admin, underadministratör eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
+    "Logged in account must be an admin or sub admin" : "Inloggat konto måste vara en admin eller underadministratör",
+    "Logged in account must be an admin" : "Inloggat konto måste vara admin",
     "Wiping of device %s has started" : "Rensning av enhet %s har startat",
     "Wiping of device »%s« has started" : "Rensning av enhet »%s« har startat",
     "»%s« started remote wipe" : "»%s« startade fjärrensning",
@@ -92,7 +93,7 @@ OC.L10N.register(
     "App \"%s\" cannot be installed because it is not compatible with this version of the server." : "Appen \"%s\" kan inte installeras eftersom den inte är kompatibel med den här versionen av servern.",
     "__language_name__" : "Svenska",
     "This is an automatically sent email, please do not reply." : "Detta är ett automatiskt e-postmeddelande, du kan därmed inte svara på det.",
-    "Help" : "Hjälp",
+    "Help & privacy" : "Hjälp & integritet",
     "Appearance and accessibility" : "Utseende och tillgänglighet",
     "Apps" : "Appar",
     "Personal settings" : "Personlig information",
@@ -117,22 +118,22 @@ OC.L10N.register(
     "Headline" : "Rubrik",
     "Organisation" : "Organisation",
     "Role" : "Roll",
-    "Unknown user" : "Okänd användare",
+    "Unknown account" : "Okänt konto",
     "Additional settings" : "Övriga inställningar",
-    "Enter the database username and name for %s" : "Ange databasanvändarnamn och lösenord för %s",
-    "Enter the database username for %s" : "Ange databasanvändare för %s",
+    "Enter the database Login and name for %s" : "Ange databas-inloggning och namn för %s",
+    "Enter the database Login for %s" : "Ange databas-inloggning för %s",
     "Enter the database name for %s" : "Ange databasnamn för %s",
     "You cannot use dots in the database name %s" : "Du kan inte använda punkter i databasnamnet %s",
-    "MySQL username and/or password not valid" : "MySQL-användarnamn och/eller lösenord är felaktigt",
+    "MySQL Login and/or password not valid" : "MySQL-inloggning och/eller lösenord är felaktigt",
     "You need to enter details of an existing account." : "Du måste ange inloggningsuppgifter av ett aktuellt konto.",
     "Oracle connection could not be established" : "Oracle-anslutning kunde inte etableras",
-    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
-    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
+    "Oracle Login and/or password not valid" : "Oracle-inloggning och/eller lösenord är felaktigt",
+    "PostgreSQL Login and/or password not valid" : "PostgreSQL-inloggning och/eller lösenord är felaktigt",
     "Mac OS X is not supported and %s will not work properly on this platform. Use it at your own risk! " : "Mac OS X stöds inte och %s kommer inte att fungera korrekt på denna plattform. Använd på egen risk!",
     "For the best results, please consider using a GNU/Linux server instead." : "För bästa resultat, överväg att använda en GNU/Linux-server istället.",
     "It seems that this %s instance is running on a 32-bit PHP environment and the open_basedir has been configured in php.ini. This will lead to problems with files over 4 GB and is highly discouraged." : "Det verkar som om denna %s instans körs på en 32-bitars PHP miljö och open_basedir har konfigurerats i php.ini. Detta kommer att leda till problem med filer över 4 GB och är verkligen inte rekommenderat!",
     "Please remove the open_basedir setting within your php.ini or switch to 64-bit PHP." : "Ta bort open_basedir-inställningen i din php.ini eller växla till 64-bitars PHP.",
-    "Set an admin username." : "Ange ett användarnamn för administratören.",
+    "Set an admin Login." : "Ange en admin-inloggning.",
     "Set an admin password." : "Ange ett administratörslösenord.",
     "Cannot create or write into the data directory %s" : "Kan inte skapa eller skriva till data-katalogen %s",
     "Sharing backend %s must implement the interface OCP\\Share_Backend" : "Delningsgränssnittet %s måste implementera gränssnittet OCP\\Share_Backend",
@@ -150,7 +151,7 @@ OC.L10N.register(
     "Expiration date is in the past" : "Utgångsdatum är i det förflutna",
     "_Cannot set expiration date more than %n day in the future_::_Cannot set expiration date more than %n days in the future_" : ["Kan inte sätta ett utgångsdatum längre fram än %n dag","Kan inte sätta ett utgångsdatum längre fram än %n dagar"],
     "Sharing is only allowed with group members" : "Delning är endast tillåten med gruppmedlemmar",
-    "Sharing %s failed, because this item is already shared with user %s" : "Delning av %s misslyckades eftersom detta redan är delat med användaren %s",
+    "Sharing %s failed, because this item is already shared with the account %s" : "Delning av %s misslyckades, eftersom det här objektet redan delas med kontot %s",
     "%1$s shared »%2$s« with you" : "%1$s delade »%2$s« med dig",
     "%1$s shared »%2$s« with you." : "%1$s delade »%2$s« med dig.",
     "Click the button below to open it." : "Klicka på knappen nedan för att öppna det.",
@@ -204,14 +205,14 @@ OC.L10N.register(
     "Nov." : "Nov.",
     "Dec." : "Dec.",
     "A valid password must be provided" : "Ett giltigt lösenord måste anges",
-    "The username is already being used" : "Användarnamnet används redan",
-    "Could not create user" : "Kunde inte skapa användare",
-    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i ett användarnamn: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
-    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
-    "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
-    "Username must not consist of dots only" : "Användarnamnet får inte innehålla enbart punkter",
-    "Username is invalid because files already exist for this user" : "Användarnamnet är ogiltigt eftersom det redan finns filer för den här användaren",
-    "User disabled" : "Användare inaktiverad",
+    "The Login is already being used" : "Inloggningen används redan",
+    "Could not create account" : "Kunde inte skapa konto",
+    "Only the following characters are allowed in an Login: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i en inloggning: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
+    "A valid Login must be provided" : "En giltig inloggning måste anges",
+    "Login contains whitespace at the beginning or at the end" : "Inloggningen innehåller blanksteg i början eller slutet",
+    "Login must not consist of dots only" : "Inloggningen får inte innehålla enbart punkter",
+    "Login is invalid because files already exist for this user" : "Inloggningen är ogiltigt eftersom det redan finns filer för den här användaren",
+    "Account disabled" : "Konto inaktiverat",
     "Login canceled by app" : "Inloggningen avbruten av appen",
     "App \"%1$s\" cannot be installed because the following dependencies are not fulfilled: %2$s" : "Appen \"%1$s\" kan inte installeras eftersom följande beroenden inte är uppfyllda: %2$s",
     "a safe home for all your data" : "ett säkert hem för all din data",
@@ -244,8 +245,8 @@ OC.L10N.register(
     "Please ask your server administrator to restart the web server." : "Be din serveradministratör att starta om webbservern.",
     "The required %s config variable is not configured in the config.php file." : "Den nödvändiga konfigurationsvariabeln %s är inte konfigurerad i filen config.php.",
     "Please ask your server administrator to check the Nextcloud configuration." : "Be din serveradministratör att kontrollera Nextcloud-konfigurationen.",
-    "Your data directory is readable by other users." : "Din datakatalog kan läsas av andra användare.",
-    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
+    "Your data directory is readable by other people." : "Din datakatalog kan läsas av andra användare.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other people." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare.",
     "Your data directory must be an absolute path." : "Din datakatalog måste vara en absolut sökväg.",
     "Check the value of \"datadirectory\" in your configuration." : "Kontrollera värdet på \"datadirectory\" i din konfiguration.",
     "Your data directory is invalid." : "Din datakatalog är ogiltig.",
@@ -267,12 +268,30 @@ OC.L10N.register(
     "Summarizes text by reducing its length without losing key information." : "Sammanfattar text genom att minska dess längd utan att förlora viktig information.",
     "Extract topics" : "Extrahera ämnen",
     "Extracts topics from a text and outputs them separated by commas." : "Extraherar ämnen från en text och matar ut dem separerade med kommatecken.",
-    "The files of the app %1$s were not replaced correctly. Make sure it is a version compatible with the server." : "Filerna i appen %1$s ersattes inte korrekt. Kontrollera att det är en version som är kompatibel med servern.",
     "404" : "404",
-    "Full name" : "Fullständigt namn",
-    "libxml2 2.7.0 is at least required. Currently %s is installed." : "libxml2 2.7.0 är det minsta som krävs. För närvarande är %s installerat.",
-    "To fix this issue update your libxml2 version and restart your web server." : "För att åtgärda detta problem uppdatera libxml2 versionen och starta om din webbserver.",
+    "Logged in user must be an admin, a sub admin or gotten special right to access this setting" : "Inloggad användare måste vara en admin, sub-admin eller ha tilldelats speciella rättigheter för att komma åt denna inställning",
+    "Logged in user must be an admin or sub admin" : "Inloggad användare måste vara administratör eller del-administratör",
+    "Logged in user must be an admin" : "Inloggad användare måste vara administratör",
+    "Help" : "Hjälp",
+    "Unknown user" : "Okänd användare",
+    "Enter the database username and name for %s" : "Ange databasanvändarnamn och lösenord för %s",
+    "Enter the database username for %s" : "Ange databasanvändare för %s",
+    "MySQL username and/or password not valid" : "MySQL-användarnamn och/eller lösenord är felaktigt",
+    "Oracle username and/or password not valid" : "Oracle-användarnamnet och/eller lösenordet är felaktigt",
+    "PostgreSQL username and/or password not valid" : "PostgreSQL-användarnamnet och/eller lösenordet är felaktigt",
+    "Set an admin username." : "Ange ett användarnamn för administratören.",
+    "Sharing %s failed, because this item is already shared with user %s" : "Delning av %s misslyckades eftersom detta redan är delat med användaren %s",
+    "The username is already being used" : "Användarnamnet används redan",
+    "Could not create user" : "Kunde inte skapa användare",
+    "Only the following characters are allowed in a username: \"a-z\", \"A-Z\", \"0-9\", spaces and \"_.@-'\"" : "Endast följande tecken är tillåtna i ett användarnamn: \"a-z\", \"A-Z\", \"0-9\", mellanslag och \"_.@-'\"",
+    "A valid username must be provided" : "Ett giltigt användarnamn måste anges",
+    "Username contains whitespace at the beginning or at the end" : "Användarnamnet består av ett mellanslag i början eller i slutet",
+    "Username must not consist of dots only" : "Användarnamnet får inte innehålla enbart punkter",
+    "Username is invalid because files already exist for this user" : "Användarnamnet är ogiltigt eftersom det redan finns filer för den här användaren",
+    "User disabled" : "Användare inaktiverad",
     "PostgreSQL >= 9 required." : "PostgreSQL >= 9 krävs.",
-    "Please upgrade your database version." : "Uppgradera din databasversion."
+    "Please upgrade your database version." : "Uppgradera din databasversion.",
+    "Your data directory is readable by other users." : "Din datakatalog kan läsas av andra användare.",
+    "Please change the permissions to 0770 so that the directory cannot be listed by other users." : "Ändra behörigheterna till 0770 så att katalogen inte kan listas av andra användare."
 },
 "nplurals=2; plural=(n != 1);");
